+++
title = "Centralized Multivariable Control By Simplified Decoupling"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
: [Decoupled Control](decoupled_control.md)

Reference
: ([Garrido, Vázquez, and Morilla 2012](#org32a9ef5))

Author(s)
: Garrido, J., Francisco V\\'azquez, & Morilla, F.

Year
: 2012


## Introduction {#introduction}

Most decoupling approaches use the conventional decoupling scheme in Figure [1](#org265d382) with:

-   \\(G(s)\\) the process matrix
-   \\(D(s)\\) the decoupler matrix
-   \\(C(s)\\) the diagonal control matrix

The design of the decoupler is obtained from:

\begin{equation}
D(s) = G^{-1} (s) \cdot Q(s)
\end{equation}

where \\(Q(s)\\) is the desired apparent process which is a diagonal matrix.

The main problem of this methodology is the fact that the complexity of the decoupler elements increases for high dimensional MIMO processes, which may require model reductions.

An alternative decoupling methods, called _inverted decoupling_, maintains very simple apparent processes and decoupler element independently of the system size.
However, inverted decoupling cannot be applied to processes with multivariable [Right Half Plane Zeros](right_half_plane_zeros.md).

<a id="org265d382"></a>

{{< figure src="/ox-hugo/garrido12_decoupling_control_system.png" caption="Figure 1: Block diagram of a decoupling control system" >}}

This work focuses on one of the most extended forms of conventional decoupling called simplified decoupling, in  which \\(n\\) elements of the decoupler are set to unity.
When the system has two inputs and two outputs (TITO), the simplified decoupling \\(G(s)\\) is given by:

\begin{equation}
D(s) = \begin{bmatrix}
1 & -g\_{12}(s)/g\_{11}(s) \\\\\\
-g\_{21}(s)/g\_{22}(s) & 1
\end{bmatrix}
\end{equation}

And the decoupled apparent process \\(Q(s)\\) is given by:

\begin{equation}
Q(s) = G(s) \cdot D(s) = \begin{bmatrix}
g\_{11}(s) - \frac{g\_{21}(s g\_{12}(s))}{g\_{22}(s)} & 0 \\\\\\
0 & g\_{22}(s) - \frac{g\_{21}(s)g\_{12}(s)}{g\_{11}(s)}
\end{bmatrix}
\end{equation}

In cases where the system is larger than 2x2, the decoupler elements set to unity are always the diagonal ones as found using:

\begin{equation}
D(s) = G(s)^{-1} (\text{diag}(G(s)^{-1}))^{-1}
\end{equation}

In this work, a simplified decoupling strategy is proposed for stable processes with possibly RHP zeros and time delays.


## Methodology {#methodology}

Assuming that the process \\(G(s)\\) may have RHP zeros and time delays, but does not have any unstable poles, the decoupler matrix \\(D(s)\\) is obtained as follows (one of many possible configurations):

\begin{equation}
D(s) = \begin{bmatrix}
1 & \frac{\text{adj}G\_{12}}{\text{adj}G\_{22}} & \dots & \frac{\text{adj}G\_{1n}}{\text{adj}\_{nn}} \\\\\\
\frac{\text{adj}G\_{21}}{\text{adj}G\_{11}} & 1 & \dots & \frac{\text{adj}G\_{2n}}{\text{adj}\_{nn}} \\\\\\
\vdots & \vdots & \ddots & \vdots \\\\\\
\frac{\text{adj}G\_{n1}}{\text{adj}G\_{11}} & \frac{\text{adj}G\_{n2}}{\text{adj}G\_{22}} & \dots & 1
\end{bmatrix}
\end{equation}

And the decoupled apparent plant is:

\begin{equation}
A(s) = \begin{bmatrix}
\frac{|G|}{\text{adj}G\_{11}} & 0 & \dots & 0 \\\\\\
0 & \frac{|G|}{\text{adj}G\_{22}} & \dots & 0 \\\\\\
\vdots & \vdots & \ddots & \vdots \\\\\\
0 & 0 & \dots & \frac{|G|}{\text{adj}G\_{nn}}
\end{bmatrix}
\end{equation}

where \\(|G(s)|\\) is the determinant of \\(G(s)\\), \\(\text{adj}G(s)\\) is the adjugate matrix of \\(G(s)\\), that is, the transpose of the cofactor matrix of \\(G(s)\\).

The proposed general simplified decoupling control is performed in three steps:

1.  select a configuration: select the \\(n\\) elements of \\(D(s)\\) to be set to unity, one for each column
2.  Compose the decoupler elements of \\(D(s)\\)
3.  Design the \\(n\\) controllers of the diagonal control \\(C(s)\\) for the decoupled processes

The realizability requirement for the decoupler is that all of its elements must be proper, causal and stable.
For processes with time delays, non-minimum phase zeros or different relative degrees, direct calculation of the decoupler element can lead to elements with RHP poles or negative relative degrees.

Several advice for the proper chose of the configuration are given in the paper.


## Design and practical considerations {#design-and-practical-considerations}

It is usually necessary to approximate the expressions of \\(|G(s)|\\) and \\(\text{adj}G(s)\\) as it usually give non-rational expressions.


## Bibliography {#bibliography}

<a id="org32a9ef5"></a>Garrido, Juan, Francisco Vázquez, and Fernando Morilla. 2012. “Centralized Multivariable Control by Simplified Decoupling.” _Journal of Process Control_ 22 (6):1044–62. <https://doi.org/10.1016/j.jprocont.2012.04.008>.
