+++
title = "The design of high performance mechatronics - third revised edition"
author = ["Dehaeze Thomas"]
description = "Awesome book that gives great overview of high performance mechatronic systems"
keywords = ["Metrology", "Mechatronics", "Control"]
draft = false
+++

Tags
: [Reference Books]({{< relref "reference_books.md" >}}), [Dynamic Error Budgeting]({{< relref "dynamic_error_budgeting.md" >}})

Reference
: (<a href="#citeproc_bib_item_1">Schmidt, Schitter, and Rankers 2020</a>)

Author(s)
: Schmidt, R. M., Schitter, G., &amp; Rankers, A.

Year
: 2020


## Applied Physics in Mechatronic Systems {#applied-physics-in-mechatronic-systems}


### Introduction {#introduction}


### Mechanics {#mechanics}

> The core of a mechatronic system is its mechanical construction and in spite of many decade of excellent designs, optimizing the mechanical structure in strength, mass and endurance, the mechanical behavior will always remain the limiting factor of the performance of any mechatronic system.


#### Coordinate Systems {#coordinate-systems}


##### Cartesian Coordinate System {#cartesian-coordinate-system}


##### Generalised Coordinate System {#generalised-coordinate-system}


##### Modal Coordinate System {#modal-coordinate-system}


#### Force and Motion {#force-and-motion}

> _Statics_ deals with the stress levels that are present in the mechanical system when (quasi-)static forces are exerted on it.
> It analyses the linear and non-linear strain effects that are caused by elastic and plastic deformation under these stress levels.
>
> _Dynamics_ deals with the behaviour of the mechanical system under changing forces, while often the effects are linearised and limited to strain levels well below any irreversible plastic deformation.
> One should however be aware that another non-destructive source of non-linearity is found in a tried important field of mechanics, called _kinematics_.
> The relation between angles and positions is often non-linear in such a mechanism, because of the changing angles, and controlling these often requires special precautions to overcome the inherent non-linearities by linearisation around actual position and adapting the optimal settings of the controller to each position.


##### Galilei and Newton's Laws of Motion {#galilei-and-newton-s-laws-of-motion}


##### Hooke's Law of Elasticity {#hooke-s-law-of-elasticity}


##### Lagrange Equations of Motion {#lagrange-equations-of-motion}


### Electricity and Magnetism {#electricity-and-magnetism}


#### Electric Field {#electric-field}

<a id="figure--fig:schmidt20-electrical-field"></a>

{{< figure src="/ox-hugo/schmidt20_electrical_field.svg" caption="<span class=\"figure-number\">Figure 1: </span>Charges have an electric field" >}}


##### Potential Difference and Capacitance {#potential-difference-and-capacitance}


##### Electric Current in Conductive Material {#electric-current-in-conductive-material}


#### Magnetism and the Maxwell Equations {#magnetism-and-the-maxwell-equations}


#### Electric Sources and Elements {#electric-sources-and-elements}


##### Voltage Source {#voltage-source}


##### Summary on Voltage and Current {#summary-on-voltage-and-current}


##### Electric Power {#electric-power}


##### Ohm's Law {#ohm-s-law}


##### Practical Values and Summary {#practical-values-and-summary}


### Signal Theory and Wave Propagation {#signal-theory-and-wave-propagation}


#### The Concept of Frequency {#the-concept-of-frequency}

The variation of an electric signal over time can be seen as a combination of three types of behavior:

-   constant, called **DC**
-   periodically alternative, called **AC**
-   Random, called **noise**

Let's consider position with an harmonic oscillation with constant angular speed \\(\omega\\) and amplitude \\(x\_p\\):

\begin{equation}
x(t) = x\_p \sin(\omega t)
\end{equation}

The angular speed \\(\omega\\) is rad/s related to the frequency \\(f\\) in hertz by:

\begin{equation}
\omega = 2\pi f \quad \text{[rad/s]}
\end{equation}

The time period of one cycle \\(T\\) in seconds is inversely proportional to \\(f\\):

\begin{equation}
T = \frac{1}{f} \quad \text{[s]}
\end{equation}

The velocity \\(v(t)\\) equals the derivative of the position over time:

\begin{equation}
v(t) = \frac{dx(t)}{dt} = \dot{x}(t) = v\_p \cos(\omega t) = x\_p \omega \cos(\omega t)
\end{equation}

Meaning that the amplitude of the velocity is:

\begin{equation}
v\_p = x\_p \omega \quad \text{[m/s]}
\end{equation}

And the acceleration \\(a(t)\\) equals the derivative of velocity over time:

\begin{equation}
a(t) = \frac{dv(t)}{dt} = \ddot{x}(t) = -x\_p \omega^2 \sin(\omega t)
\end{equation}

It could be concluded that velocity either advances on position with a phase of 90 degrees or lags with a phase of 270 degrees.
The second option is however not logical as the position of an object is the result of **and thus comes after** the velocity.
The same phase relation exists between the velocity and the acceleration.

Noise is a real random non-deterministic signal,which means that the signal value at any time of observation can have any value within a certain range.
The range is described by means of a statistical distribution, which indicates the probability that the value is within that range.
The distribution of frequencies contained in the noise, called the _frequency spectrum_, can only be described in statistical terms.

Sometimes electronic signals are represented by their power value, being the squared momentary value.
In case of a voltage signal, this power value would be equal to the power dissipated in a \\(1 \Omega\\) resistor.
In an alternating signal, the power also varies over time.
When examining the power of a signal, as defined by the squared momentary value, often the average power over time \\(\bar{P\_s}\\) is taken as a representative number:

\begin{equation}
\bar{P\_s} = \frac{1}{T}\int\_0^T \left<f(t)\right>^2 dt \quad [W]
\end{equation}

In the example of a voltage signal over a \\(1\Omega\\) resistor this average power level would be equal to the power dissipated in the resistor by a DC voltage with a value of:

\begin{equation}
V\_{\text{rms}} = \sqrt{\frac{1}{T}\int\_0^T \left<f(t)\right>^2 dt}
\end{equation}

The term "rms" refers to Root Mean Square, named from the action of taking the root of the mean value of the squared function.
The RMS value is a well known term used to characterize the "useful" value of the energy supply with a signal by comparing it with an equivalent DC voltage that would cause the same power in a resistive load.

<div class="exampl">

For a sinusoidal signal \\(V(t) = V\_p \sin(\omega t)\\), the equivalent DC voltage becomes:

\begin{equation}
\begin{aligned}
V\_{\text{rms}} &= \sqrt{\frac{1}{T} \int\_0^T \left< V\_p\sin(\omega t) \right>^2 dt} \\\\
               &= \dots \\\\
               &= \frac{V\_p}{\sqrt{2}} \quad [V]
\end{aligned}
\end{equation}

</div>


#### Use of Complex Numbers {#use-of-complex-numbers}


##### Dynamic Impedance and Ohm's Law {#dynamic-impedance-and-ohm-s-law}


##### Power in Dynamic Impedance {#power-in-dynamic-impedance}


##### Capacitive Impedance {#capacitive-impedance}


##### Inductive Impedance {#inductive-impedance}


#### Energy Propagation in Waves {#energy-propagation-in-waves}

The energy in a traveling wave is transferred to another place by a consecutive process called _propagation_ at a velocity, which is called propagation velocity or _phase velocity_ \\(v\_p\\) [m/s], a spatial vector with a magnitude, called propagation speed \\(c\_p\\) [m/s].
When observing a continuous sinusoidal wave motion on a stationary position, the observed value, like displacement or pressure, will appear to vary with a certain **temporal** frequency \\(f\\) [Hz] with period \\(T\\) [s], which is determined by the source of the wave.
With a certain propagation speed \\(c\_p\\), the temporal frequency \\(f\\) will also correspond to a **spatial** variation of the observed value along the propagation direction at a stationary moment in time.
This spatial frequency is called the _wavenumber_ \\(\nu\\) [1/m], and equals the number of periods of the wave per meter.
Its inverse, the spatial period length called _wavelength_ \\(\lambda\\) [m] is more common.

The relation between the above defined terms is:

\begin{align}
  \lambda &= \frac{1}{\nu} = c\_p T = \frac{c\_p}{f} \quad [m] \\\\
  v\_p     &= \frac{f}{\nu} \quad [m/s]
\end{align}


##### Mechanical Waves {#mechanical-waves}

The propagation speed value of a mechanical wave is mostly determined by the density and elasticity of the medium.
The wave propagation through an elastic material can be qualitatively explained with the help of a simplified lumped element model, consisting of a chain of springs and bodies as shown in Figure [2](#figure--fig:schmidt20-mechanical-wave).

<a id="figure--fig:schmidt20-mechanical-wave"></a>

{{< figure src="/ox-hugo/schmidt20_mechanical_wave.svg" caption="<span class=\"figure-number\">Figure 2: </span>Lumped element model of one wavelength of a mechanical wave." >}}

To explain the principle of energy transfer, the longitudinal wave is taken as example.
When a movement of mass \\(m\_1\\) is introduced in the propagation direction of the chain, this will first cause a compression of the elastic coupling \\(k\_1\\).
The resulting compression force is transferred to mass \\(m\_2\\), which accelerates resulting in its own movement and causing in its turn a compression of \\(k\_2\\).
This process is repeated over the total chain until the original movement reaches \\(m\_n\\).
With this mechanism the kinetic energy from mass \\(m\_1\\) is converted into potential energy in \\(k\_1\\), which in turn is transferred into kinetic energy of \\(m\_2\\), and so on.

<div class="important">

This phenomenon of transfer of energy in an elastic body is important in mechatronic systems because driving forces are also transported through the body as a wave and as a consequence will experience a delay between the actuator and the sensor when they are located separately.

</div>

The propagation speed \\(c\_p\\) is determined by the density \\(\rho\_m\\) and the elasticity of the medium, expressed by the Young's modulus \\(Y\\) for a wave running in one direction in a solid rod and bulk modulus \\(B\\) for a wave running in a volume and equals:

\begin{equation}
\text{1-D: } c\_p = \sqrt{\frac{Y}{\rho\_m}}, \quad \text{3-D: } c\_p = \sqrt{\frac{B}{\rho\_m}} \quad [m/s]
\end{equation}

<div class="exampl">

The propagation speed in stainless steel varies between 3500 m/s for transversal waves and 5500 m/s for longitudinal waves.
With for instance half a meter of steel this gives a delay of about 0.1ms, resulting in a phase delay of 36 degrees at 1kHz, which can be significant from a control point of view.

</div>


##### Wave Equation {#wave-equation}


##### Electromagnetic Waves {#electromagnetic-waves}


##### Reflection of Waves {#reflection-of-waves}


##### Standing Waves {#standing-waves}


#### Fourier Decomposition of Alternating Signals {#fourier-decomposition-of-alternating-signals}


##### Fourier in the frequency-domain {#fourier-in-the-frequency-domain}


##### Triangle Waveform {#triangle-waveform}

{{< figure src="/ox-hugo/schmidt20_fourier_triangle.svg" >}}


##### Sawtooth Waveform {#sawtooth-waveform}

{{< figure src="/ox-hugo/schmidt20_fourier_sawtooth.svg" >}}


##### Square Waveform {#square-waveform}

{{< figure src="/ox-hugo/schmidt20_fourier_square.svg" >}}


##### Non-Continuous Alternating Signals {#non-continuous-alternating-signals}

{{< figure src="/ox-hugo/schmidt20_window_functions.svg" >}}


### Dynamic System Analysis and Modelling {#dynamic-system-analysis-and-modelling}


#### Laplace-Transform {#laplace-transform}

The Laplace transform can be used to solve differential equations of motion, which could describe the position of an object in the time-domain, by solutions in the frequency domain in the form of a _transfer-function_ with the Laplace operator \\(s = \sigma + j\omega\\).

The Laplace operator \\(s = \sigma + j\omega\\) is a complex number that can graphically be represented in a two dimensional plot called the _Laplace-plane_ with the value of \\(\sigma\\) on the horizontal real axis and \\(j\omega\\) on the vertical imaginary axis.

In case \\(f(t)\\) is a function of the time variable \\(t\\), then the Laplace-transformed function \\(F(s) = \mathcal{L}\\{f(t)\\}\\) is described as a function of the Laplace operator \\(s\\) in the following way:

\begin{equation}
\boxed{ F(s) = \mathcal{L}\\{f(t)\\} = \int\_0^\infty e^{-st}f(t)dt }
\end{equation}

The Laplace transform converts a differential of a variable \\(x(t)\\) over time into the following function:

\begin{equation}
\mathcal{L}\left\\{ \frac{dx(t)}{dt} \right\\} = s x(s) - x(0)
\end{equation}

In practice, the initial value \\(x(0)\\) of \\(x(t)\\) at \\(t=0\\) is neglected for the dynamic analysis of mechatronic systems as the frequency response functions are based on the continuous presence of the input signal of the system.

The Laplace transform applied to an integration action gives the following function:

\begin{equation}
\mathcal{L}\left\\{ \int\_0^{t^\prime} x(t) dt \right\\} = \frac{x(s)}{s}
\end{equation}

The Laplace plane is used when examining the stability of a dynamic system, determined by the location of the poles and zeros of the dynamic transfer function of the system after transforming its equations of motion.
A transfer function is generally a function with polynomial terms of \\(s\\) in the numerator and the denominator.
A zero is defined as the value of \\(s\\) in the transfer function at which the numerator equals zeros.
A pole is defined as the value of \\(s\\) in the transfer function at which the denominator equals zeros, in that case the total transfer function becomes infinite.

Any real physical systems always have more poles than zeros, because of the fact that no real physical system can respond to an infinite frequency.

The order of a dynamic system can be defined as:

-   the number of energy containers like mass, spring
-   the number of state variables
-   the number of poles


#### Dynamic Responses in the time-domain {#dynamic-responses-in-the-time-domain}


##### Step Response {#step-response}


##### Impulse Response {#impulse-response}


##### Impulse Response and Pole Location {#impulse-response-and-pole-location}

{{< figure src="/ox-hugo/schmidt20_impulse_response_location.svg" >}}


#### Dynamic Responses in the frequency-domain {#dynamic-responses-in-the-frequency-domain}


##### Frequency or Fourier-Domain Responses {#frequency-or-fourier-domain-responses}


##### Domain Notation of Dynamic Functions {#domain-notation-of-dynamic-functions}


##### Frequency Response Plots {#frequency-response-plots}


##### Bode Plot {#bode-plot}

{{< figure src="/ox-hugo/schmidt20_bode_plot.svg" >}}

Instead of using absolute numbers with the magnitude scale, often the scale is divided in decibels.
The unit "Bel" corresponds to the log of the ratio of powers, and therefore the term "deci-bel" corresponds to:

\begin{equation}
10 \log\frac{P\_1}{P\_2} \quad [dB]
\end{equation}

As the signals are proportional to the square root of power, we obtain that:

\begin{equation}
20 \log\frac{V\_1}{V\_2} \quad [dB]
\end{equation}

In terms of decibel, the slope in the Bode plot becomes equal to a certain number of dB per frequency ratio.
The values are given in Table [1](#table--tab:relation-slope-decade) for a decade (representing a factor ten between the frequencies), and in Table [2](#table--tab:relation-slope-octave) for an octave (factor two between the frequencies).

<a id="table--tab:relation-slope-decade"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:relation-slope-decade">Table 1</a>:</span>
  Relation between the order of the slope of a bode plot and the magnitude ration in dB, amplitude ratio and power ration, per <b>decade</b> (\(f_1 = 10 f_2\))
</div>

| Slope | dB  | Amplitude     | Power         |
|-------|-----|---------------|---------------|
| -2    | -40 | \\(10^{-2}\\) | \\(10^{-4}\\) |
| -1    | -20 | 0.1           | \\(10^{-2}\\) |
| 0     | 0   | 1             | 1             |
| 1     | 20  | 10            | \\(10^{2}\\)  |
| 2     | 40  | \\(10^2\\)    | \\(10^{4}\\)  |

<a id="table--tab:relation-slope-octave"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:relation-slope-octave">Table 2</a>:</span>
  Relation between the order of the slope of a bode plot and the magnitude ration in dB, amplitude ratio and power ration, per <b>octave</b> (\(f_1 = 2 f_2\))
</div>

| Slope | dB  | Amplitude | Power  |
|-------|-----|-----------|--------|
| -2    | -12 | 0.25      | 0.0625 |
| -1    | -6  | 0.5       | 0.25   |
| 0     | 0   | 1         | 1      |
| 1     | 6   | 2         | 4      |
| 2     | 12  | 4         | 16     |


##### Nyquist Plot {#nyquist-plot}

{{< figure src="/ox-hugo/schmidt20_nyquist_plot.svg" >}}


##### Limitation to LTI Systems {#limitation-to-lti-systems}


## Dynamics of Motion Systems {#dynamics-of-motion-systems}


### Introduction {#introduction}


### Stiffness {#stiffness}


#### Importance of Stiffness for Precision {#importance-of-stiffness-for-precision}


#### Active Stiffness {#active-stiffness}


### Mass-Spring Systems with Damping {#mass-spring-systems-with-damping}


#### Dynamic Compliance {#dynamic-compliance}


##### Compliance of a Spring {#compliance-of-a-spring}


##### Compliance of a Damper {#compliance-of-a-damper}


##### Compliance of a Body {#compliance-of-a-body}


##### Dynamic Stiffness {#dynamic-stiffness}


##### Lumping the Dynamic Elements {#lumping-the-dynamic-elements}


#### Transfer Function of Compliance {#transfer-function-of-compliance}


##### Damped Mass-Spring System. {#damped-mass-spring-system-dot}


##### Magnitude {#magnitude}


##### Phase {#phase}


##### Bode Plot {#bode-plot}


#### Effects of Damping {#effects-of-damping}


##### Damped Resonance and Aperiodic Damping {#damped-resonance-and-aperiodic-damping}


##### Poles and Critical Damping {#poles-and-critical-damping}


##### Quality-Factor Q and Energy in Resonance {#quality-factor-q-and-energy-in-resonance}


#### Transmissibility {#transmissibility}


#### Fourth-Order Dynamic System {#fourth-order-dynamic-system}


##### Analytical Description {#analytical-description}


##### Multiplicative Expression {#multiplicative-expression}


##### Effect of Different Mass Ratios {#effect-of-different-mass-ratios}


### Modal Decomposition {#modal-decomposition}


#### Eigenmodes of Two-Body Mass-Spring System {#eigenmodes-of-two-body-mass-spring-system}


#### Theory of Modal Decomposition {#theory-of-modal-decomposition}


##### Multi Degree of Freedom Equation of Motion {#multi-degree-of-freedom-equation-of-motion}


##### Eigenvalues and Eigenvectors {#eigenvalues-and-eigenvectors}


##### Modal Coordinates {#modal-coordinates}


##### Resulting Transfer Function {#resulting-transfer-function}


#### Graphical Representation of Mode-Shapes {#graphical-representation-of-mode-shapes}


##### Traditional Representation {#traditional-representation}


##### Lever Representation {#lever-representation}


##### General System {#general-system}


##### User-Defined Physical DOF {#user-defined-physical-dof}


#### Physical Meaning of Modal Parameters {#physical-meaning-of-modal-parameters}


##### Two-Body Mass-Spring System {#two-body-mass-spring-system}


##### Planar Flexibly Guided System {#planar-flexibly-guided-system}


#### A Pragmatic View on Sensitivity Analysis {#a-pragmatic-view-on-sensitivity-analysis}


##### Example of Two Body Mass-Spring System {#example-of-two-body-mass-spring-system}


##### Example of Slightly Damped Resonance {#example-of-slightly-damped-resonance}


#### Suspension and Rigid-Body Modes {#suspension-and-rigid-body-modes}


##### Quasi Rigid-Body Suspension mode {#quasi-rigid-body-suspension-mode}


### Mechanical Frequency Response {#mechanical-frequency-response}


#### Multiple eigenmodes {#multiple-eigenmodes}


#### Characteristic Frequency Responses {#characteristic-frequency-responses}


##### Frequency Response Type I {#frequency-response-type-i}


##### Frequency Response Type II {#frequency-response-type-ii}


##### Frequency Response Type III {#frequency-response-type-iii}


##### Frequency Response Type IV {#frequency-response-type-iv}


#### Example Systems with Type I/II/IV Response {#example-systems-with-type-i-ii-iv-response}


##### Planar Moving Body on Compliant Spring {#planar-moving-body-on-compliant-spring}


##### H-drive Waferstage {#h-drive-waferstage}


### Summary on Dynamics {#summary-on-dynamics}

<div class="sum">

In this chapter some important lessons have been learned, which are summarised as follows:

-   Stiffness, whether it is created mechanically or by means of a control system, is determinative for precision
-   Every mechanical structure can be modelled as a combination of bodies, springs and dampers, either as separate bodies or as finite elements within a body
-   Phase is prominent factor regarding the possibility to control the motion of a mechanical system
-   The quality factor \\(Q\\) and damping ratio \\(\xi\\) are inverse proportional. Each have their practical value.
-   A damping placed in parallel with a lumped mass-spring system limits the magnitude of the resonance at the natural frequency.
    However, it also increases the transmissibility at frequencies above the native frequency.
-   The dynamic behavior of a complex system and its response to a stimulus can be derived and understood by viewing it as a superposition of contributions of its eigenmodes, each with its own mode-shape, eigenfrequency, modal parameters and damping.
-   The position of the actuator and the sensors determine the observability and controllability of the different eigenmodes, which is characterised by four typical frequency response.
-   A precision design requires a careful lay-out of all elements, considering the eigenmodes.
-   Modal analysis is a powerful and widely applied tool to investigate the dynamics of a mechanical structure.

Finally it can be concluded, that these insights help in designing actively controlled dynamic motion systems with optimally located actuators and sensors, which reduce the sensitivity for modal dynamic problems.

</div>


## Motion Control {#motion-control}


### A Walk around the Control Loop {#a-walk-around-the-control-loop}

Figure [3](#figure--fig:schmidt20-walk-control-loop) shows a basic control loop of a positioning system.
First, the A/D and D/A converters are used to translate analog signals into time-discrete digital signals and vice versa.
Secondly, the impact locations of several disturbances are shown, which play a large role in determining what reqwuirements the controller needs to fulfil.
The core of the control system is the _plant_, which is the physical system that needs to be controlled.

<a id="table--tab:walk-control-loop"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:walk-control-loop">Table 3</a>:</span>
  Symbols used in Figure <a href="#org4b1b612">3</a>
</div>

| Symbol     | Meaning                              | Unit |
|------------|--------------------------------------|------|
| \\(r\\)    | Reference signal                     | [m]  |
| \\(r\_f\\) | Filtered reference signal            | [m]  |
| \\(e\\)    | Error signal                         | [m]  |
| \\(u\\)    | Control force that should be applied | [N]  |
| \\(v\\)    | Real force that is applied           | [N]  |
| \\(x\\)    | Plant output motion                  | [m]  |
| \\(y\\)    | Measured output motion               | [m]  |
| \\(y\_m\\) | Measurement value                    | [m]  |

<a id="figure--fig:schmidt20-walk-control-loop"></a>

{{< figure src="/ox-hugo/schmidt20_walk_control_loop.svg" caption="<span class=\"figure-number\">Figure 3: </span>Block diagram of a motion control system, including feedforward and feedback control." >}}

The plant combines the mechanical structure, amplifiers and actuators, as they all deal with energy conversion in close interaction (Figure [4](#figure--fig:schmidt20-energy-actuator-system)).
They interact in both directions in such a way that each element not only determines the input of the next element, but also influences the previous element by its dynamic load.

<a id="figure--fig:schmidt20-energy-actuator-system"></a>

{{< figure src="/ox-hugo/schmidt20_energy_actuator_system.svg" caption="<span class=\"figure-number\">Figure 4: </span>The energy converting part of a mechatronic system consists of a the amplifier, the actuator and the mechanical structure." >}}


#### Poles and Zeros in Motion Control {#poles-and-zeros-in-motion-control}

Any transfer function derived from a system can be represented with poles \\(p\_n\\) and zeros \\(z\_m\\):

\begin{equation}
G(s) = \frac{(s-z\_1)(s-z\_2)\dots(s-z\_m)}{(s-p\_1)(s-p\_2)\dots(s-p\_n)}
\end{equation}

with \\(m < n\\).

The number of poles is an indicator of the order of the dynamic system, corresponding to the number of states (position and velocity) and the number of energy containers (mass, spring).
All real system are _strictly proper_ with more poles and zeros.
Even though zeros can not create instability, the term _unstable zeros_ is given to zeros in the right half of the Laplace-plane (positive real term) for two reasons:

-   inverting an unstable zero will result in an unstable pole
-   it indicates non-minimum phase behavior, meaning a larger negative phase shift than would be expected from the slope of the amplitude Bode plot.

It also shows a counter intuitive step response, because the initial motion is directed opposite to the direction of the force.

It is usually caused by the non-collocated sensor in respect to the actuator.
In reality all mechatronic feedback systems have not perfectly collocated sensors and as a consequence they may show some level of non-minimum phase behaviour.
Fortunately the effect is mostly so small that it can be neglected.


#### Overview Feedforward Control {#overview-feedforward-control}

Figure [5](#figure--fig:schmidt20-feedforward-control-diagram) shows the typical basic configuration for feedforward control, which is also called _open-loop control_ as it is equal to a situation where the measured output is not connected to the input for feedback.

The reference signal \\(r\\) [m] is applied to the controller, which as a reference transfer function \\(C\_{ff}(s)\\) in [N/m].
The output \\(u\\) in [N] of the controller is connected to the input of the motion system, which has a transfer function \\(G(s)\\) in [m/N] giving the output \\(x\\) in [m].
In this configuration the feedforward controller acts as a filter, which modifies the reference signal in such a way, that the motion of the controlled mechatronic system follows the reference signal.

If one would like to achieve perfect control, which means that there is no difference between the reference position and the actual position of the system, the combined transfer function \\(G\_{t,ff}(s)\\) from \\(r\\) to \\(x\\) has to be equal to one:

\begin{equation}
G\_{t,ff}(s) = \frac{x}{r} = C\_{ff}(s)G(s) = 1 \quad \Longrightarrow \quad C\_{ff}(s) = G^{-1}(s)
\end{equation}

<a id="figure--fig:schmidt20-feedforward-control-diagram"></a>

{{< figure src="/ox-hugo/schmidt20_feedforward_control_diagram.svg" caption="<span class=\"figure-number\">Figure 5: </span>Block diagram of a feedforward controller motion system with one input and output (SISO)." >}}

<div class="important">

Feedforward control is a very useful and preferred first step in the control of a complex dynamic motion system as it provides the following advantages:

-   **Less feedback required**: the better the feedforward part is performing the smaller the feedback error will need to be corrected further errors. This is the most important reason that feedforward control is always applied to the maximum accuracy possible in fast high precision motion systems.
-   **No sensor required**: no sensor information is fed back to the system, which means that a sensor can be left out, thus reducing the cost of pure feedforward controlled systems.
-   **Predictable movement**: if the reference signal (trajectory) is known in advance, the phase-lag and time delay in the system can be predicted and therefore compensated.
-   **No introduction of instability**: the poles of the controlled system are not changed by feedforward control. Therefore no instability can be introduced.
-   **No feeding back of sensor noise**: in precision motion systems, positioning noise is a critical point that always has to be considered in the control design. The lack of a sensor avoid insertion of the measurement noise in the system.

</div>

<div class="important">

The drawbacks and limitations of feedforward control are:

-   **Limitation to inverted low-pass minimum-phase characteristic**:  it is not possible nor wise to create a controller with a very high gain at very high frequencies. Inverting unstable zeros for a non-minimum phase system would create an unstable controller.
-   **The plant has to be stable**: Unstable systems cannot be controlled with pure feedforward control.
-   **No compensation of model uncertainties**: Variations in the system dynamics, such as shifting of the resonance frequency or variation of the damping, are not monitored and therefore not accounted for in feedforward control.
-   **Can only compensate for known disturbances**: Disturbances of the motion system can only be compensated if they can be measured.

</div>


#### Overview Feedback Control {#overview-feedback-control}

In feedback control the actuator status of the motion system is monitored by a sensor and the controller generates a control action based on the difference between the desired motion (reference signal) and the actuator system status (sensor signal).

The block diagram of Figure [6](#figure--fig:schmidt20-feedback-control-diagram) shows a SISO feedback loop for a motion system without the A/D and D/A converters.
The output \\(x\\) in [m] is the total motion of the plant on all its parts and details, while \\(y\\) is the measured motion with a measured value \\(y\_m\\) measured on a selected location in the plant.
This measured is compared with \\(r\_f\\), which is the reference \\(r\\) after filtering.
The result of this comparison is used as input for the feedback controller.

<div class="note">

The transfer function of any input to any output in a closed-loop feedback controlled dynamic system is equal to the forward path from the input to the output divided by one plus the transfer function of the total feedback path.

</div>

<a id="figure--fig:schmidt20-feedback-control-diagram"></a>

{{< figure src="/ox-hugo/schmidt20_feedback_control_diagram.svg" caption="<span class=\"figure-number\">Figure 6: </span>Block diagram of a SISO feedback controlled motion system." >}}

In control design, one has the freedom to choose \\(F(s)\\) and particularly \\(C\_{fb}(s)\\) such that the total transfer function fulfills the desired specifications.
Feedback control allows to directly place the system poles at values that are more useful for the operation of the motion system that their natural locations.
This enables a faster response of the system with adequate damping and also enable unstable plants to be stabilized.

The input filter does not contribute to this important aspect of feedback.
It is mainly used to present unwanted signals from entering the system.
This can be signals that drive the system into its "incapability" region where the system can no longer perform as required due to limitations in the hardware.

<div class="important">

Feedback is an addition to feedforward control with the following benefits:

-   **Stabilization of unstable systems**: As feedback control enables to determine the place of the closed-loop poles of the controlled system, unstable poles can be stabilised.
-   **Reduction of the effect of disturbances**: Disturbances of the controlled motion system are observed in the sensor signal, and therefore the feedback controller can compensate for them.
-   **Handling of uncertainties**: Feedback controlled systems can also be designed for _robustness_, which means that the stability and performance requirements are guaranteed even for parameter variations of the controlled mechatronic system.

</div>

<div class="important">

Also, some pitfalls have to be dealt with:

-   **A sensor is required**: The feedback loop is closed, based on the information from a sensor. Therefore, feedback control can be only as good as the quality of the sensor signal allows. In precision positioning systems accurate sensors are required with high resolution and fast response, which are very costly. The measurement and sensing system often takes a substantial part of the total systems budget.
-   **Limited reaction speed**: A feedback controller only reacts on difference between the reference signal and the measured system status, which means that the error has to occur first before the controller can correct for it.
-   **Feedback of noise**: By closing the loop, the positioning noise of the motion system as well as sensor noise are also fed back, which has to be considered at the system and control design.
-   **Can introduce instability**: Just as feedback control can stabilize an unstable system, it can also destabilize a stable plant.
-   **Can increase errors**: With higher order systems feedback will reduce errors in the frequency band where the loop-gain is larger than one and increase errors just outside that band.

</div>


#### Summary {#summary}

<a id="table--tab:feedback-feedforward-sum"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:feedback-feedforward-sum">Table 4</a>:</span>
  Summary of Feedback and Feedforward control
</div>

|                 | **Advantages**                          | **Limitations**                                              |
|-----------------|-----------------------------------------|--------------------------------------------------------------|
| **Feedback**    | Stabilization of unstable systems       | A sensor is required                                         |
|                 | Reduction of the effect of disturbances | Limited reaction speed                                       |
|                 | Handling of uncertainties               | Feedback of noise                                            |
|                 |                                         | Can introduce instability                                    |
|                 |                                         | Can increase errors                                          |
| **Feedforward** | Less feedback required                  | Limitation to inverted low-pass minimum-phase characteristic |
|                 | No sensor required                      | The plant has to be stable                                   |
|                 | Predictable movement                    | No compensation of model uncertainties                       |
|                 | No introduction of instability          | Can only compensate for known disturbances                   |
|                 | No feeding back of sensor noise         |                                                              |


### Feedforward Control {#feedforward-control}


#### Model-Based Feedforward Control {#model-based-feedforward-control}

In the following an example of a model-based feedforward controller is introduced.
The measured frequency-response of the scanning unit taken as as an example is shown in Figure [7](#figure--fig:schmidt20-bode-plot-scanning).

<a id="figure--fig:schmidt20-bode-plot-scanning"></a>

{{< figure src="/ox-hugo/schmidt20_bode_plot_scanning.svg" caption="<span class=\"figure-number\">Figure 7: </span>Bode plot of a piezoelectric-actuator based scanning unit for nanometer resolution positioning. It shows the measured response (solid line) and the second order model, which is fitted for the low-frewquency system behaviour (dashed line)." >}}

A mathematical model of a seconder-order mass-spring system with a force input is fitted to this measured response:

\begin{equation}
G(s) = \frac{C\_f \omega\_0^2}{s^2 + 2\xi\_f \omega\_0 s + \omega\_0^2}
\end{equation}

When positioning at high scanning frequency, the resonance at the first mode-shape of this scanning unit causes oscillations, which adversely affect the tracking accuracy.
In order to solve this problem, a feedforward controller is designed that compensate the dynamics of the scanner by first inverting the transfer function of the plan, without changing the static gain of the positioning system.
This means that the transfer function of the feedforward controller is:

\begin{equation}
C\_{ff}(s) = \frac{s^2 + 2 \xi\_f \omega\_0 s + \omega\_0^2}{\omega\_0^2}
\end{equation}

However, such controller needs to be modified in such a way that it becomes _realizable_.
In this case, it is decided to create a resulting overall transfer function of the controller and the plant that acts like a well damped mass-spring system with the same natural frequency as the plant and an additional reduction of the excitation of high frequency eigen-modes.
In order to realize this controller, first two poles have to be added:

\begin{equation}
C\_{ff}(s) = \frac{s^2 + 2 \xi\_f \omega\_0 s + \omega\_0^2}{s^2 + 2\cdot 1 \cdot \omega\_0 s + \omega\_0^2}
\end{equation}

There the damping ratio of the resulting dynamics is chosen to be \\(\xi = 1\\).

This feedforward controller is basically a _notch filter_.
In order to create an additional attenuation of higher frequency resonances due to flexible-body mode-shapes, another first-order pole is added at the first eigenfrequency:

\begin{equation}
C\_{ff}(s) = \frac{s^2 + 2 \xi\_f \omega\_0 s + \omega\_0^2}{(s + \omega\_0)(s^2 + 2\omega\_0 s + \omega\_0^2)}
\end{equation}

Then this controller is connected in series with the scanning unit, the anti-resonance of the controller and the resonance of the piezo-scanner cancel each other out:

\begin{align}
G\_{t,ff}(s) &= G(s)G\_{ff}(s) \\\\
            &= \frac{C\_f}{s^2 + 2 \xi\_f \omega\_0 s + \omega\_0^2} \frac{s^2 + 2 \xi\_f \omega\_0 s + \omega\_0^2}{(s + \omega\_0){s^2 + 2 \omega\_0 s + \omega\_0^2}} \\\\
            &= \frac{C\_f}{(s + \omega\_0){s^2 + 2 \omega\_0 s + \omega\_0^2}}
\end{align}

The bode plot of the resulting dynamics is shown in Figure [8](#figure--fig:schmidt20-bode-plot-feedfoward-example).
The controlled system has low-pass characteristics, rolling of at the scanner's natural frequency.

<a id="figure--fig:schmidt20-bode-plot-feedfoward-example"></a>

{{< figure src="/ox-hugo/schmidt20_bode_plot_feedfoward_example.svg" caption="<span class=\"figure-number\">Figure 8: </span>Bode plot of the feedforward-controlled scanning unit" >}}


#### Input-Shaping {#input-shaping}

Another often applied control method is _input-shaping_.
Instead of applying a filter in the frequency domain, with this method the reference signal is modified in the time-domain.
As an example, the piezoelectric actuator driven scanning unit is used.
When applying a step signal to the scanning unit, it would start of oscillate at its natural frequency.
In a first approximation, the scanner can be assumed to behave like a linear system, which means that a reduction of the input step stimulus by a factor of two would result in a reduction of the amplitude of the response by the same factor two.

The idea is that instead of applying one step, two steps with half amplitude are applied with the second step delayed by half the period of the scanner's resonance frequency.
The oscillation caused by each individual step are 180 degrees out of phase and cancel each other out.
This method is clearly very different form pole-zero cancellation.
In the frequency domain, these sampled adaptations to the input create a frequency spectrum with a multiple of notch filters at the harmonic of the frequency where these adaptations are applied.

Applying input-shaping to the triangular scanning signal results in the introduction of a plateau instead of the sharp peak, where the width of the plateau corresponds to half the period of the scanner's resonance as can be seen in Figure [9](#figure--fig:schmidt20-input-shaping-example).

<a id="figure--fig:schmidt20-input-shaping-example"></a>

{{< figure src="/ox-hugo/schmidt20_input_shaping_example.svg" caption="<span class=\"figure-number\">Figure 9: </span>Input-shaping control of the triangular scanning signal in a scanning probe microscope." >}}


#### Adaptive Feedforward Control {#adaptive-feedforward-control}

Both examples of feedforward control, the model-based pole-zero cancellation and the input-shaping, only work reliably as long as the dynamic properties of the total plant are known and _remain constant_.
There is always some deviation between the parameters in the model and the reality.
This deviation can be partly solved by _adaptive feedforward control_, adapting the feedforward signal by measuring the real behavior of the system.
This method requires a sensor to obtain information about the response of the system and for that reason it is often applied in combination with feedback.

For repetitive processed, the required feedforward signal can be derived from the previous cycles.
This version of adaptive feedforward control is called _Iterative Learning Control_ (ILC).


#### Trajectory Profile Generation {#trajectory-profile-generation}

The limitations of the actuators and electronics in a controlled motion system are usually related to limitations in the derivatives over time of the position:

-   \\(dx/dt\\) = Velocity
-   \\(d^2x/dt^2\\) = Acceleration
-   \\(d^3x/dt^3\\) = Jerk
-   \\(d^4x/dt^4\\) = Snap

Of at least the levels of Jerk and preferable also Snap should be limited.
The standard method to cope with these limitations involves shaping the input of a mechatronic motion system by means of _trajectory profile generation_ or _path-planning_.

Figure [10](#figure--fig:schmidt20-trajectory-profile) shows a fourth order trajectory profile of a displacement, which means that all derivatives including the fourth derivative are defined in the path planning.
A third order trajectory would show a square profile for the jerk indicating an infinite Snap and the round of the acceleration would be gone.
A second order trajectory would show a square acceleration profile with infinite Jerk and sharp edges on the velocity.

<a id="figure--fig:schmidt20-trajectory-profile"></a>

{{< figure src="/ox-hugo/schmidt20_trajectory_profile.svg" caption="<span class=\"figure-number\">Figure 10: </span>Figure caption" >}}


### Feedback Control {#feedback-control}

Feedforward control can improve the performance of an open-loop stable system with known properties and circumstances.
However, there is always some remaining errors than need to be corrected by feedback control.

Feedback control is more complex and critical to design than feedforward control due the inherent risk of instability.

> On might say that a high value of the unity-gain crossover frequency and corresponding high-frequency bandwidth limit is rather an unwanted side-effect of the required high loop-gain at lower frequencies, than a target for the design of a control system as such.


#### Sensitivity to Input Signals {#sensitivity-to-input-signals}

In general, a feedback controlled motion system is to perform a certain predetermined motion task defined by the reference input \\(r\\), while reducing the effects of other inputs like external vibrations and noise from the electronics.
All these input signals, whether desired of undesired, are treated by the feedback loop as disturbances and it is the sensitivity of the desired output signal to all input signals that determine the performance of the feedback controller.

<a id="figure--fig:schmidt20-feedback-full-simplified"></a>

{{< figure src="/ox-hugo/schmidt20_feedback_full_simplified.svg" caption="<span class=\"figure-number\">Figure 11: </span>Full and simplified representation of a feedback loop in order to determine the influence of the reference signal and most important disturbance sources on real motion output of the plant \\(x\\), the feedback controller output \\(u\\) and the measured motion output \\(y\\). \\(y\_m = y\\) when the measurement system is set at unity gain and the sensor disturbance is included in the output disturbance." >}}

Several standard sensitivity functions have been defined to quantify the performance of feedback controlled dynamic systems.
There are derived from a simplified version of the generic feedback loop as shown in Figure [11](#figure--fig:schmidt20-feedback-full-simplified).
The first simplification is made by approximating the measurement system to have a unity-gain transfer function.
For further simplification the sensor disturbance in the measurement system is included in the output disturbance \\(n\\), thereby defining the output of the system \\(y\\) as the measured output.
With this simplified model, the transfer functions of the different inputs of the system to three relevant output variables in the loop are written down in a set of equations.
Six different transfer functions are obtained and summarized in equation <eq:gang_of_six>.

\begin{equation} \label{eq:gang\_of\_six}
\begin{aligned}
 \frac{x}{r} &= \frac{y}{r} = \frac{GCF}{1 + GC} \\\\
-\frac{x}{n} &= -\frac{u}{d} = \frac{GC}{1 + GC} \\\\
 \frac{x}{d} &= \frac{y}{d} = \frac{G}{1 + GC} \\\\
 \frac{u}{r} &= \frac{CF}{1 + GC} \\\\
 \frac{u}{n} &= \frac{C}{1 + GC} \\\\
 \frac{y}{n} &= \frac{1}{1 + GC}
\end{aligned}
\end{equation}

In case no input filter is applied \\(F\\) is equal to one and the set of six equations is reduced to a set of four equations as shown in equation <eq:gang_of_four>.
This short set of equations also corresponds to the situation without a reference signal.

The most important transfer function is named the _Sensitivity Function_ (no unit):

\begin{equation}
S(s) = \frac{1}{1 + GC}
\end{equation}

It represents the sensitivity of the output to a disturbance on the output.

Then, the _Process Sensitivity Function_ (in [m/N]):

\begin{equation}
GS(s) = \frac{G}{1 + GC}
\end{equation}

which represents the sensitivity of the output to disturbances inside and before the plant.

Finally, the _Complementary Sensitivity Function_ (no unit):

\begin{equation}
T(s) = \frac{GC}{1 + GC}
\end{equation}

represents the ability of the system to follow a given reference position signal.
For motion systems, the complementary sensitivity function is less important, because using model-based feedforward control for handling known inputs, feedback should only be applied for correction of unknown factors caused by disturbing inputs.
For that reason the most relevant motion system performance criteria are the Sensitivity \\(S(s)\\) and the Process Sensitivity \\(GS(s)\\).

\begin{equation} \label{eq:gang\_of\_four}
\boxed{\begin{aligned}
\frac{x}{r} &= \frac{y}{r} = -\frac{x}{n} = -\frac{u}{d} = \frac{GC}{1 + GC} \\\\
\frac{x}{d} &= \frac{y}{d} = \frac{G}{1 + GC} \\\\
\frac{u}{r} &= \frac{u}{n} = \frac{C}{1 + GC} \\\\
\frac{y}{n} &= \frac{1}{1 + GC}
\end{aligned}}
\end{equation}

A common factor in all the sensitivity functions is the _Feedback-loop Transfer Function_:

\begin{equation}
L(s) = G(s) C\_{fb}(s)
\end{equation}

The magnitude of the _Feedback-loop response_ \\(L(j\omega)\\) is called the _loop-gain_.

The sensitivity functions were defined as the impact of any of the inputs to the measured output \\(y\\).
In reality, we would be more interested in errors at the real position \\(x\\).
We can compute the error \\(e\_{\text{real}} = r - x\\) and find:

\begin{equation}
e\_{\text{real}} = r - x = \sqrt{(S(s)r)^ 2 + (GS(s)d)^2 + (T(s)n)^2} \quad \text{[m]}
\end{equation}

This clearly points out that a high control gain \\(C(s)\\) only reduces errors related to the reference and the process disturbance but not the errors included in \\(n\\) that originate in the measurement system, because \\(T(s)\\) will approach unity with a high control gain.
The quality of the sensor therefore determines the _minimal_ achievable error.


#### Stability and Robustness in Feedback Control {#stability-and-robustness-in-feedback-control}

To achieve sufficient robustness against instability in closed-loop feedback control of a motion system, several margins are defined that are applied in the analysis of the transfer function of the feedback loop.

The condition for robustness of closed-loop stability is that the total phase-lag of the **total feedback-loop**, consisting of the feedback controller in series with the mechatronic system, must be less than 180 degrees in the frequency region of the _unity-gain cross-over frequency_.

The Nyquist plot of the feedback loop, like the example shown in Figure [12](#figure--fig:schmidt20-nyquist-plot-stable), is most appropriate to analyze the robustness on stability of a feedback system.
It is an analysis tool that shows the frequency response of the **feedback-loop** combining magnitude and phase in one plot.
In this figure, two graphs are shown, designed for a different purpose.
The first graph from the left shows margin circles related to the capability of the closed-loop feedback controlled system to follow a reference according to the complementary sensitivity.
The second graph shows a margin circle related to the capability of the closed-loop feedback controlled system to suppress disturbances according to the sensitivity function.

<a id="figure--fig:schmidt20-nyquist-plot-stable"></a>

{{< figure src="/ox-hugo/schmidt20_nyquist_plot_stable.svg" caption="<span class=\"figure-number\">Figure 12: </span>Nyquist plot of the feedback-loop response of a stable feedback controlled motion system. Stability is guaranteed as the \\(-1\\) point is kept at the left hand side of the feedback loop repsonse line upon passing with increased frequency, even though the phase-lag is more than 180 degrees at low frequencies." >}}

Three values are shown in Figure [12](#figure--fig:schmidt20-nyquist-plot-stable) related to the robustness of the closed-loop feedback system:

-   **The gain margin** determines by which factor the feedback loop gain additionally can increase before the closed-loop goes unstable.
-   **The phase margin** determines how much additional phase-lab at the unity-gain cross-over frequency is acceptable before the closed-loop system becomes unstable.
-   **The modulus margin** is defined by the closest distance in a Nyquist plot between the graph and the \\(-1\\) point. It determines the highest level of the Sensitivity \\(S(s)\\) in the frequency range where the error is increased by feedback.

The robustness margins determine how much the properties of the system are allowed to change before the system becomes unstable.
With smaller margins, the system will behave more nervous, less damped.
Higher margins corresponds to a higher level of damping.

The Nyquist plot has one significant disadvantage as it does not show directly the frequency along the plot.
For that reason many designers prefer to use the Bode plot.

Fortunately it is also possible to indicate the phase and gain margin in the Bode plot as is shown in Figure [13](#figure--fig:schmidt20-phase-gain-margin-bode).

In many not too complicated cases, these two margins are sufficient to tune a feedback motion controller.
In more complicated control systems, it remains useful to also use the Nyquist plot as it also gives the Modulus margin.

<a id="figure--fig:schmidt20-phase-gain-margin-bode"></a>

{{< figure src="/ox-hugo/schmidt20_phase_gain_margin_bode.svg" caption="<span class=\"figure-number\">Figure 13: </span>The gain and phase margin in the Bode plot" >}}


### PID Feedback Control {#pid-feedback-control}


#### PID-Control of a Compact-Disc Player {#pid-control-of-a-compact-disc-player}


##### Relevant Sensitivity Functions {#relevant-sensitivity-functions}


##### Proportional Feedback {#proportional-feedback}


##### Proportional-Differential Feedback {#proportional-differential-feedback}


##### Limiting the Differentiating Action {#limiting-the-differentiating-action}


##### Adding I-Control {#adding-i-control}


#### PID-Control of a Spring Supported Mass {#pid-control-of-a-spring-supported-mass}


##### P-Control {#p-control}


##### D-Control {#d-control}


##### I-Control {#i-control}


##### Sensitivity Function Graphs {#sensitivity-function-graphs}


#### Limitations and Side Effects of PID-Feedback Control {#limitations-and-side-effects-of-pid-feedback-control}


##### Increased Sensitivity, the Waterbed Effect {#increased-sensitivity-the-waterbed-effect}


##### Integrator Wind-Up and Delays {#integrator-wind-up-and-delays}


#### PID-Control of a Fourth-Order Dynamic System {#pid-control-of-a-fourth-order-dynamic-system}


##### Controlling a Type III Dynamic System {#controlling-a-type-iii-dynamic-system}


##### Passive Damping {#passive-damping}


##### Shifting the Phase {#shifting-the-phase}


#### PID-Control of a Piezoelectric Actuator {#pid-control-of-a-piezoelectric-actuator}


##### Creating a Fourth-Order System {#creating-a-fourth-order-system}


#### PID-Control of a Magnetic Bearing {#pid-control-of-a-magnetic-bearing}


##### Frequency Response {#frequency-response}


##### Positive Stiffness by P-Control {#positive-stiffness-by-p-control}


##### D-Control and Pole Placement {#d-control-and-pole-placement}


##### I-control for Reduced Sensitivity {#i-control-for-reduced-sensitivity}


#### Optimisation by Loop-Shaping Design {#optimisation-by-loop-shaping-design}


##### Optimal Value of Alpha {#optimal-value-of-alpha}


##### Additional Low-Pass Filtering {#additional-low-pass-filtering}


##### Notching Filters {#notching-filters}


##### Peaking and Shelving Filters {#peaking-and-shelving-filters}


#### Design Steps for PID-control {#design-steps-for-pid-control}


### Digital Signal Processing - The Z-Domain {#digital-signal-processing-the-z-domain}

Most modern controllers operate with digital processors in the discrete time domain, also called the _Z-domain_, which allows to create filters by combining scaled sampled data at fixed intervals.
In many situations it is sufficient to design the system by creating the control filters in continuous-time frequency responses and use a corresponding transformation that translates the filters into their discrete-time counterparts.
In the transition to a digital and discrete time implementation the phase lag introduced by delay and latency of the sampling, calculation and communication process needs to be considered.
This is mostly fine when the sample frequency is very high (\\(\gg 10\\) times) in respect to the bandwidth of the controlled system.


#### Continuous Time versus Discrete Time {#continuous-time-versus-discrete-time}

In the frequency-domain a position controller acts as a filter, which attenuates or amplifies the system response and shapes the phase response of the system in certain frequency areas.
In principle these filters, all representing a differential equation or a transfer function with poles and zeros, can be implemented in analogue electronics or as a digital filter that runs on a digital real-time hardware computing platform.

The implementation of a filter in analogue electronics, allows the realization of very high bandwidth frequencies at low cost.
However, analogue controllers have three important disadvantages:

-   its properties can be less consistent over time and also sensitive to changing environmental conditions such as temperature
-   each filter parameter has to be adjusted in hardware by selecting discrete passive components, which cannot be adapted easily during operation
-   the noise of the filter and its propagation has to be considered in the design process

The digital implementation of filters overcome these problems as well as allows more complex algorithm such as adaptive control, real-time optimization, nonlinear control and learning control methods.

In Figure [14](#figure--fig:schmidt20-digital-implementation) two elements were introduced, the _analogue-to-digital converter_ (ADC) and the _digital-to-analogue converter_ (DAC), which together transfer the signals between the analogue and the digital domain.

<a id="figure--fig:schmidt20-digital-implementation"></a>

{{< figure src="/ox-hugo/schmidt20_digital_implementation.svg" caption="<span class=\"figure-number\">Figure 14: </span>Overview of a digital implementation of a feedback controller, emphasising the analog-to-digital and digital-to-analog converters with their required analogue filters" >}}

Anti-aliasing filter is needed at the input of the ADC to limit the frequency range at the input to less than half the sampling frequency, according to the Nyquist-Shannon sampling theorem.

A DAC needs a filter (called a reconstruction of _anti-imaging_ filter) at its analogue output, because the digital data are provided at fixed intervals after which they are kept constant between each sampling moments by means of a zero-order hold element.

The selection of the resolution of ADCs and DACs determines the resolution and achievable precision of the controlled motion system, while the choice of the sampling time determines the maximum frequency that the filter can correctly handles.


#### Sampling of Continuous Signals {#sampling-of-continuous-signals}


#### Digital Number Representation {#digital-number-representation}

For the implementation of digital algorithms on digital computing platforms, two representation forms of digital number exist, floating point or fixed point.

Fixed point arithmetic has been favored in the past, because of the less complex DSP processor structure.
A main drawback is, that the developer must pay attention to truncation, overflow, underflow and round-off errors that occur during mathematical operations.
Fixed points numbers are equally spaced over the whole range, separated by the gap which is denoted by the least significant bit.
The two's complement is the most used format for representing positive and negative numbers.
For representing a fixed point fractional number of two's complement notation, the so called \\(Q\_{m,n}\\) format is often used (see Figure [15](#figure--fig:schmidt20-digital-number-representation)).
\\(m\\) denotes the number of integer bits and \\(n\\) denotes the number of fractional bits.
\\(m+n+1=N\\) bits are necessary to store a signed \\(Q\_{m,n}\\) number.
If the binary representation is given, the decimal value can be calculated to:

\begin{equation}
x = \frac{1}{2^n} \left( -2^{N-1 }b\_{N-1} + \sum\_{i=0}^{N-2} 2^i b\_i \right)
\end{equation}

where \\(b\\) indicate the bit position, starting with \\(b\_0\\) from the right in Figure [15](#figure--fig:schmidt20-digital-number-representation).

<a id="figure--fig:schmidt20-digital-number-representation"></a>

{{< figure src="/ox-hugo/schmidt20_digital_number_representation.svg" caption="<span class=\"figure-number\">Figure 15: </span>Example of a \\(Q\_{m.n}\\) fixed point number representation and a single precision floating point number" >}}

Floating point arithmetic has a higher dynamic range than fixed point arithmetic, given by the largest and smallest number that can be represented, has a higher precision due to the smaller gaps between adjacent numbers, less quantization noise, and it is easier to handle in terms of programming.
A floating point number is represented by a multiplication of a _mantissa_ \\(M\\) with a _base_ \\(b\\) to the power of the _exponent_ \\(q\\):

\begin{equation}
x = -1^i M b^q
\end{equation}

A common used standard for representing floating point numbers defines basic formats, single precision (32 bit wide format) and double precision (64 bit wide format).
The single precision format with a base of 2 is chosen as an example.
The decimal value can be calculated by:

\begin{equation}
x = -1^i M 2^{E-127}
\end{equation}

The term \\(E\\) in the exponent is stored as a positive number ranging from \\(0 \le E < 256\\) with 8 bits.
An offset of \\(-127\\) is added in order to allow very small to very large numbers.
The decimal value is normalized, meaning that only one nonzero digit is noted at the left of the decimal point.
The storage register is divided into three groups, as shown in Figure [15](#figure--fig:schmidt20-digital-number-representation).
1 bit represents the sign, the exponent term \\(E\\) is represented by 8 bits, and the mantissa is stored in 23 bits.


#### Digital Filter Theory {#digital-filter-theory}

<a id="figure--fig:schmidt20-s-z-planes"></a>

{{< figure src="/ox-hugo/schmidt20_s_z_planes.svg" caption="<span class=\"figure-number\">Figure 16: </span>Corresponding points and area in s and z planes" >}}


#### Finite Impulse Response (FIR) Filter {#finite-impulse-response--fir--filter}

<a id="figure--fig:schmidt20-transversal-filter-structure"></a>

{{< figure src="/ox-hugo/schmidt20_transversal_filter_structure.svg" caption="<span class=\"figure-number\">Figure 17: </span>Transversal filter structure of a FIR filter. The term \\(z^{-1}\\) each represent a sampling period which means that \\(b\_0\\) is the gain of the last sample, \\(b\_1\\) is the gain of the precious sample etcetera." >}}

<a id="figure--fig:schmidt20-optimized-fir-filter-structure"></a>

{{< figure src="/ox-hugo/schmidt20_optimized_fir_filter_structure.svg" caption="<span class=\"figure-number\">Figure 18: </span>Optimized FIR filter structure with symmetric filter coefficients" >}}

<a id="figure--fig:schmidt20-dir-filter-cascaded-sos"></a>

{{< figure src="/ox-hugo/schmidt20_dir_filter_cascaded_sos.svg" caption="<span class=\"figure-number\">Figure 19: </span>Higher-order FIR filter realization with cascade SOS filter structures" >}}


#### Infinite Impulse Response (IIR) Filter {#infinite-impulse-response--iir--filter}

<a id="figure--fig:schmidt20-irr-structure"></a>

{{< figure src="/ox-hugo/schmidt20_irr_structure.svg" caption="<span class=\"figure-number\">Figure 20: </span>(a:) IIR structure in DF-1 realization and (b:) IIR structure in DF-2 realization" >}}

<a id="figure--fig:schmidt20-irr-sos-structure"></a>

{{< figure src="/ox-hugo/schmidt20_irr_sos_structure.svg" caption="<span class=\"figure-number\">Figure 21: </span>IIR SOS structure in DF-2 realization" >}}


#### Converting Continuous to Discrete-Time Filters {#converting-continuous-to-discrete-time-filters}


### State-Space Feedback Control {#state-space-feedback-control}


#### State-Space in Relation to Motion Control {#state-space-in-relation-to-motion-control}


##### Mechanical Dynamic System in State-Space {#mechanical-dynamic-system-in-state-space}


##### PID-Control Feedback in State-Space {#pid-control-feedback-in-state-space}


#### State Feedback {#state-feedback}


##### System Identification {#system-identification}


##### State Estimation {#state-estimation}


##### Additional Remarks on State-Space Control {#additional-remarks-on-state-space-control}


### Conclusion on Motion Control {#conclusion-on-motion-control}

<div class="sum">

Motion control is essential for Precision Mechatronic Systems and consists of two complementary elements:

-   **Extremely accurate Feedforward Control** is required when the motion system must execute a user defined motion to within maximum user defined position error limits.
    The forces required for this task are known upfront and can generally not be generated by feedback control only given the limited allowable position error and physical limitations on achievable loop-gain of feedback control.
-   **High Performance Feedback Control** is required when the motion system must be able to follow an unknown motion of a target, stabilize an otherwise unstable system and reduce the impact of disturbing forces and vibrations, such that the position error remains below a maximum user defined level.
    Due to the fact that a feedback controller can become unstable, sufficient robustness must be guaranteed.
    These is a conflicting relation between stability and performance.

</div>


## Electromechanic Actuators {#electromechanic-actuators}


### Introduction {#introduction}


### Electromagnetics {#electromagnetics}


#### Hopkinson's Law {#hopkinson-s-law}


##### Practical Aspects of Hopkinson's Law {#practical-aspects-of-hopkinson-s-law}


##### Magnetic Energy {#magnetic-energy}


#### Ferromagnetic Materials {#ferromagnetic-materials}


##### Coil with Ferromagnetic Yoke {#coil-with-ferromagnetic-yoke}


##### Magnetisation Curve {#magnetisation-curve}


##### Permanent Magnets {#permanent-magnets}


#### Creating a Magnetic Field in an Air-Gap {#creating-a-magnetic-field-in-an-air-gap}


##### Optimal Use of Permanent Magnet Material {#optimal-use-of-permanent-magnet-material}


##### Flat Magnets Reduce Fringing Flux {#flat-magnets-reduce-fringing-flux}


##### Low Cost Loudspeaker Magnet {#low-cost-loudspeaker-magnet}


### Lorentz Actuator {#lorentz-actuator}


#### Lorentz Force {#lorentz-force}


##### Force from Flux-Linkage {#force-from-flux-linkage}


#### The Lorentz actuator as a Generator {#the-lorentz-actuator-as-a-generator}


#### Improving the Force of a Lorentz Actuator {#improving-the-force-of-a-lorentz-actuator}


##### The Moving-Coil Loudspeaker Actuator {#the-moving-coil-loudspeaker-actuator}


#### Position Dependency of the Lorentz Force {#position-dependency-of-the-lorentz-force}


##### Over-Hung and Under-Hung Coil {#over-hung-and-under-hung-coil}


#### Electronic Commutation {#electronic-commutation}


##### Three-Phase Electronic Control {#three-phase-electronic-control}


#### Figures of Merit of a Lorentz Actuator {#figures-of-merit-of-a-lorentz-actuator}


### Variable Reluctance Actuation {#variable-reluctance-actuation}


#### Reluctance Force in Lorentz Actuator {#reluctance-force-in-lorentz-actuator}


##### Eddy-Current Ring {#eddy-current-ring}


##### Ironless Stator {#ironless-stator}


#### Analytical Derivation of Reluctance Force {#analytical-derivation-of-reluctance-force}


#### Variable Reluctance Actuator. {#variable-reluctance-actuator-dot}


##### Electromagnetic Relay {#electromagnetic-relay}


##### Magnetic Attraction Force {#magnetic-attraction-force}


#### Permanent Magnet Biased Reluctance Actuator {#permanent-magnet-biased-reluctance-actuator}


##### Double Variable Reluctance Actuator {#double-variable-reluctance-actuator}


##### Constant Common Flux {#constant-common-flux}


##### Combining two Sources of Magnetic Flux {#combining-two-sources-of-magnetic-flux}


##### Hybrid Force Calculation {#hybrid-force-calculation}


##### Magnetic Bearings {#magnetic-bearings}


#### Active Linearisation of the Reluctance Force {#active-linearisation-of-the-reluctance-force}


### Application of Electromagnetic Actuators {#application-of-electromagnetic-actuators}


#### Electrical Interface Properties {#electrical-interface-properties}


##### Dynamic Effects of Self-Inductance {#dynamic-effects-of-self-inductance}


##### Limitation of the \`\`Jerk'' {#limitation-of-the-jerk}


##### Electromagnetic Damping {#electromagnetic-damping}


#### Comparison of three Electromagnetic Actuators {#comparison-of-three-electromagnetic-actuators}


##### Force-Constants {#force-constants}


##### Figures of Merit Including Mass {#figures-of-merit-including-mass}


##### Stiffness {#stiffness}


##### Repeatability and Predictability {#repeatability-and-predictability}


##### Dynamic Effects on the Control Loop {#dynamic-effects-on-the-control-loop}


### Piezoelectric Actuators {#piezoelectric-actuators}


#### Piezoelectricity {#piezoelectricity}


##### Poling {#poling}


##### Tapping the Bound Charge by Electrodes {#tapping-the-bound-charge-by-electrodes}


#### Transducer Models {#transducer-models}


#### Nonlinearity of Piezoelectric Actuators {#nonlinearity-of-piezoelectric-actuators}


##### Creep {#creep}


##### Hysteresis {#hysteresis}


##### Aging {#aging}


#### Mechanical Considerations {#mechanical-considerations}


##### Piezoelectric Actuator Stiffness {#piezoelectric-actuator-stiffness}


##### Actuator Types {#actuator-types}


##### Long Range Actuation by Friction {#long-range-actuation-by-friction}


##### Actuator Integration {#actuator-integration}


##### Mechanical Amplification {#mechanical-amplification}


##### Multiple Motion Directions by Stacking {#multiple-motion-directions-by-stacking}


#### Electrical Considerations {#electrical-considerations}


##### Charge vs. Voltage Control {#charge-vs-dot-voltage-control}


##### Self-Sensing Actuation {#self-sensing-actuation}


### Choosing the right Actuator Type {#choosing-the-right-actuator-type}


## Analogue Electronics in Mechatronic Systems {#analogue-electronics-in-mechatronic-systems}


### Introduction {#introduction}


### Passive Linear Electronics {#passive-linear-electronics}


#### Network Theory and Laws {#network-theory-and-laws}


##### Voltage Source {#voltage-source}


##### Current Source {#current-source}


##### Theorem of Norton and Thevenin {#theorem-of-norton-and-thevenin}


##### Kirchhoff's Laws {#kirchhoff-s-laws}


##### Impedances in Series or Parallel {#impedances-in-series-or-parallel}


##### Voltage Divider {#voltage-divider}


##### Maximum Power of a Real Voltage Source {#maximum-power-of-a-real-voltage-source}


#### Impedances in Electronic Circuits {#impedances-in-electronic-circuits}


##### Resistors {#resistors}


##### Capacitors {#capacitors}


##### Inductors {#inductors}


#### Passive Filters {#passive-filters}


##### Passive First-Order RC-Filters {#passive-first-order-rc-filters}


##### Passive Higher-Order RC-Filters {#passive-higher-order-rc-filters}


##### Passive LCR-Filters {#passive-lcr-filters}


#### Mechanical-Electrical Dynamic Analogy {#mechanical-electrical-dynamic-analogy}


### Semiconductors and Active Electronics {#semiconductors-and-active-electronics}


#### Basic Discrete Semiconductors {#basic-discrete-semiconductors}


##### Semiconductor Diode {#semiconductor-diode}


##### Bipolar Transistors {#bipolar-transistors}


##### MOSFET {#mosfet}


##### Other Discrete Semiconductors {#other-discrete-semiconductors}


#### Single Transistor Linear Amplifiers {#single-transistor-linear-amplifiers}


##### Emitter Follower {#emitter-follower}


##### Voltage Amplifier {#voltage-amplifier}


##### Differential Amplifier {#differential-amplifier}


#### Operational Amplifier {#operational-amplifier}


##### Basic Operational Amplifier Design {#basic-operational-amplifier-design}


##### Operational Amplifier with Feedback {#operational-amplifier-with-feedback}


#### Linear Amplifiers with Operational Amplifiers {#linear-amplifiers-with-operational-amplifiers}


##### Design Rules {#design-rules}


##### Non-Inverting Amplifier {#non-inverting-amplifier}


##### Inverting Amplifier {#inverting-amplifier}


##### Adding and Subtracting Signals {#adding-and-subtracting-signals}


##### Transimpedance Amplifier {#transimpedance-amplifier}


##### Transconductance Amplifier {#transconductance-amplifier}


#### Active Electronic Filters {#active-electronic-filters}


##### Integrator and First-Order Low-Pass {#integrator-and-first-order-low-pass}


##### Differentiator and First-Order High-Pass {#differentiator-and-first-order-high-pass}


#### Analogue PID-Controller {#analogue-pid-controller}


##### PID Transfer Function {#pid-transfer-function}


##### PID Control Gains {#pid-control-gains}


##### High-Speed PID-Control {#high-speed-pid-control}


#### Higher-order Electronic Filters {#higher-order-electronic-filters}


##### Second-Order Low-Pass Filter {#second-order-low-pass-filter}


##### Different Types of Active Filters {#different-types-of-active-filters}


#### Ideal and Real Operational Amplifiers {#ideal-and-real-operational-amplifiers}


##### Open-Loop Voltage Gain {#open-loop-voltage-gain}


##### Dynamic Limitations {#dynamic-limitations}


##### Input Related Limitations {#input-related-limitations}


##### Power Supply and Output Limitations {#power-supply-and-output-limitations}


#### Closing Remarks on Low-Power Electronics {#closing-remarks-on-low-power-electronics}


### Power Amplifiers for Motion Control {#power-amplifiers-for-motion-control}


#### Required Properties for Actuator Drive {#required-properties-for-actuator-drive}


##### Power Delivery Capability {#power-delivery-capability}


##### Dynamic Properties {#dynamic-properties}


##### Linearity, Freedom of Distortion {#linearity-freedom-of-distortion}


##### Voltage or Current Drive {#voltage-or-current-drive}


##### Efficiency {#efficiency}


##### Four-Quadrant Operation {#four-quadrant-operation}


##### Preferred Power Amplifier Principle {#preferred-power-amplifier-principle}


#### Switched-Mode Power Amplifiers {#switched-mode-power-amplifiers}


##### Power MOSFET, a Fast High-Power Switch {#power-mosfet-a-fast-high-power-switch}


##### Switching Sequence Generation {#switching-sequence-generation}


##### Voltage Drive Amplifier {#voltage-drive-amplifier}


##### Energy Flow in the Power Output Stage {#energy-flow-in-the-power-output-stage}


##### Intermediate Conclusions and Other Issues {#intermediate-conclusions-and-other-issues}


##### Driving the Power MOSFETs {#driving-the-power-mosfets}


##### Charge Pumping {#charge-pumping}


##### H-Bridge Configuration {#h-bridge-configuration}


##### Output Filter {#output-filter}


#### Resonant-Mode Power Amplifiers {#resonant-mode-power-amplifiers}


##### Switching Sequence of the Output Stage {#switching-sequence-of-the-output-stage}


##### Lossless Current Sensing {#lossless-current-sensing}


#### Three-Phase Amplifiers {#three-phase-amplifiers}


##### Concept of Three-Phase Amplifier {#concept-of-three-phase-amplifier}


##### Three-Phase Switching Power Stages {#three-phase-switching-power-stages}


#### Some Last Remarks on Power Electronics {#some-last-remarks-on-power-electronics}


## Optics in Mechatronic Systems {#optics-in-mechatronic-systems}


### Introduction {#introduction}


### Properties of Light and Light Sources {#properties-of-light-and-light-sources}


#### Light Generation by Thermal Radiation {#light-generation-by-thermal-radiation}


#### Photons by Electron Energy State Variation {#photons-by-electron-energy-state-variation}


##### Light Emitting Diodes {#light-emitting-diodes}


##### Laser as an Ideal Light Source {#laser-as-an-ideal-light-source}


#### Useful Power from a Light Source {#useful-power-from-a-light-source}


##### Radiant Emittance and Irradiance {#radiant-emittance-and-irradiance}


##### Radiance {#radiance}


##### Etendue {#etendue}


### Reflection and Refraction {#reflection-and-refraction}


#### Reflection and Refraction according to the Least Time {#reflection-and-refraction-according-to-the-least-time}


##### Partial Reflection and Refraction {#partial-reflection-and-refraction}


#### Concept of Wavefront {#concept-of-wavefront}


##### A Wavefront is Not Real {#a-wavefront-is-not-real}


### Geometric Optics {#geometric-optics}


#### Imaging with Refractive Lens Elements {#imaging-with-refractive-lens-elements}


##### Sign Conventions {#sign-conventions}


##### Real Lens Elements {#real-lens-elements}


##### Magnification {#magnification}


#### Aberrations {#aberrations}


##### Spherical Aberration {#spherical-aberration}


##### Astigmatism {#astigmatism}


##### Coma {#coma}


##### Geometric and Chromatic Aberrations {#geometric-and-chromatic-aberrations}


#### Combining Multiple Optical Elements {#combining-multiple-optical-elements}


##### Combining Two Positive Lenses {#combining-two-positive-lenses}


#### Aperture Stop and Pupil {#aperture-stop-and-pupil}


#### Telecentricity {#telecentricity}


##### Pupil, Aperture and Lens Dimensions {#pupil-aperture-and-lens-dimensions}


##### Practical Applications and Constraints {#practical-applications-and-constraints}


### Physical Optics {#physical-optics}


#### Polarisation {#polarisation}


##### Birefringence {#birefringence}


#### Interference {#interference}


##### Fabry-Perot Interferometer {#fabry-perot-interferometer}


#### Diffraction {#diffraction}


##### Amplitude gratings {#amplitude-gratings}


##### Phase Gratings {#phase-gratings}


##### Direction of the Incoming Light {#direction-of-the-incoming-light}


#### Imaging Quality based on Diffraction {#imaging-quality-based-on-diffraction}


##### Numerical Aperture and f-Number {#numerical-aperture-and-f-number}


##### Depth of Focus {#depth-of-focus}


### Adaptive Optics {#adaptive-optics}


#### Thermal Effects in Optical Imaging Systems {#thermal-effects-in-optical-imaging-systems}


#### Correcting the Wavefront {#correcting-the-wavefront}


##### Zernike Polynomials {#zernike-polynomials}


##### Correcting Zernikes by Adaptive Optics {#correcting-zernikes-by-adaptive-optics}


#### Adaptive Optics Principle of Operation {#adaptive-optics-principle-of-operation}


##### Active Mirrors {#active-mirrors}


## Measurement in Mechatronic Systems {#measurement-in-mechatronic-systems}


### Introduction {#introduction}


#### Measurement Systems {#measurement-systems}


#### Errors in Measurement Systems, Uncertainty {#errors-in-measurement-systems-uncertainty}


##### Uncertainty in Traceable Measurements {#uncertainty-in-traceable-measurements}


#### Functional Model of a Measurement System Element {#functional-model-of-a-measurement-system-element}


### Dynamic Error Budgeting {#dynamic-error-budgeting}


#### Error Statistics in Repeated Measurements {#error-statistics-in-repeated-measurements}


#### The Normal Distribution {#the-normal-distribution}


#### Combining Different Error Sources {#combining-different-error-sources}


#### Power Spectral Density and Cumulative Power {#power-spectral-density-and-cumulative-power}

{{< figure src="/ox-hugo/schmidt20_psd_cps.svg" >}}


#### Do not use the Cumulative Amplitude Spectrum! {#do-not-use-the-cumulative-amplitude-spectrum}


#### Variations in Dynamic Error Budgeting {#variations-in-dynamic-error-budgeting}


#### Sources of Noise and Disturbances {#sources-of-noise-and-disturbances}


##### Mechanical Noise {#mechanical-noise}


##### Electronic Noise {#electronic-noise}


### Sensor Signal Sensitivity {#sensor-signal-sensitivity}


#### Sensing Element {#sensing-element}


#### Converting an Impedance into an Electric Signal {#converting-an-impedance-into-an-electric-signal}


##### Wheatstone Bridge {#wheatstone-bridge}


#### Electronic Interconnection of Sensitive Signals {#electronic-interconnection-of-sensitive-signals}

{{< figure src="/ox-hugo/schmidt20_signal_interference.svg" >}}

{{< figure src="/ox-hugo/schmidt20_cable_topology.svg" >}}

{{< figure src="/ox-hugo/schmidt20_electrostatic_shielding.svg" >}}


##### Magnetic Disturbances {#magnetic-disturbances}


##### Capacitive Disturbances {#capacitive-disturbances}


##### Ground Loops {#ground-loops}

{{< figure src="/ox-hugo/schmidt20_ground_loops.svg" >}}


### Signal Conditioning {#signal-conditioning}


#### Instrumentation Amplifier {#instrumentation-amplifier}


#### Filtering and Modulation {#filtering-and-modulation}


##### AM with Square Wave Carrier {#am-with-square-wave-carrier}


##### AM with Sinusoidal Carrier {#am-with-sinusoidal-carrier}


### Signal Processing {#signal-processing}


#### Schmitt Trigger {#schmitt-trigger}

{{< figure src="/ox-hugo/schmidt20_schmitt_trigger.svg" >}}


#### Digital Representation of Measurement Data {#digital-representation-of-measurement-data}


##### Gray Code {#gray-code}

{{< figure src="/ox-hugo/schmidt20_gray_code.svg" >}}


##### Sampling of Analogue Values {#sampling-of-analogue-values}


##### Nyquist-Shannon Theorem {#nyquist-shannon-theorem}


##### Filtering to Prevent Aliasing {#filtering-to-prevent-aliasing}


#### Analogue-to-Digital Converters {#analogue-to-digital-converters}


##### Dual-Slope ADC {#dual-slope-adc}


##### Successive-Approximation ADC {#successive-approximation-adc}


##### Sigma-Delta ADC {#sigma-delta-adc}


##### ADC Latency in a Feedback Loop {#adc-latency-in-a-feedback-loop}


#### Connecting the Less Sensitive Elements {#connecting-the-less-sensitive-elements}


##### Characteristic Impedance {#characteristic-impedance}


##### Non-Galvanic Connection {#non-galvanic-connection}


### Short-Range Motion Sensors {#short-range-motion-sensors}


#### Optical Sensors {#optical-sensors}


##### Position Sensitive Detectors {#position-sensitive-detectors}


##### Optical Deflectometer {#optical-deflectometer}


#### Capacitive Position Sensors {#capacitive-position-sensors}


##### Linearising by Differential Measurement {#linearising-by-differential-measurement}


##### Accuracy Limits and Improvements {#accuracy-limits-and-improvements}


##### Sensing to Conductive Moving Plate {#sensing-to-conductive-moving-plate}


#### Inductive Position Sensors {#inductive-position-sensors}


##### Linear Variable Differential Transformer {#linear-variable-differential-transformer}


##### Eddy-Current Sensors {#eddy-current-sensors}


#### Pneumatic Proximity Sensor or Air-Gage {#pneumatic-proximity-sensor-or-air-gage}


### Measurement of Mechanical Dynamics {#measurement-of-mechanical-dynamics}


#### Measurement of Force and Strain {#measurement-of-force-and-strain}


##### Strain Gages {#strain-gages}


##### Fibre Bragg Grating Strain Measurement {#fibre-bragg-grating-strain-measurement}


#### Velocity Measurement {#velocity-measurement}


##### Geophone {#geophone}


#### Accelerometers {#accelerometers}


##### Closed-Loop Feedback Accelerometer {#closed-loop-feedback-accelerometer}


##### Piezoelectric Accelerometer {#piezoelectric-accelerometer}


##### MEMS Accelerometer {#mems-accelerometer}


### Optical Long-Range Incremental Position Sensors {#optical-long-range-incremental-position-sensors}


#### Linear Optical Encoders {#linear-optical-encoders}


##### Interpolation {#interpolation}


##### Vernier Resolution Enhancement {#vernier-resolution-enhancement}


##### Interferometric Optical Encoder {#interferometric-optical-encoder}


##### Concluding Remarks on Linear Encoders {#concluding-remarks-on-linear-encoders}


#### Laser Interferometer Measurement Systems {#laser-interferometer-measurement-systems}


##### Homodyne Distance Interferometry {#homodyne-distance-interferometry}


##### Heterodyne Distance Interferometry {#heterodyne-distance-interferometry}


##### Measurement Uncertainty {#measurement-uncertainty}


##### Configurations {#configurations}


##### Multi-Axis Laser Interferometers {#multi-axis-laser-interferometers}


#### Mechanical Aspects {#mechanical-aspects}


##### Abbe Error {#abbe-error}


## Precision Positioning in Wafer Scanners {#precision-positioning-in-wafer-scanners}


### Introduction {#introduction}


### The Waferscanner {#the-waferscanner}


#### Requirements on Precision {#requirements-on-precision}


### Dynamic Architecture {#dynamic-architecture}


#### Balance Masses {#balance-masses}


#### Vibration Isolation {#vibration-isolation}


##### Eigendynamics of the Sensitive Parts {#eigendynamics-of-the-sensitive-parts}


### Zero-Stiffness Stage Actuation {#zero-stiffness-stage-actuation}


#### Waferstage Actuation Concept {#waferstage-actuation-concept}


##### Waferstepper Long-Range Lorentz Actuator {#waferstepper-long-range-lorentz-actuator}


##### Multi-Axis Positioning {#multi-axis-positioning}


##### Long- and Short-Stroke Actuation {#long-and-short-stroke-actuation}


#### Full Magnetic Levitation {#full-magnetic-levitation}


#### Acceleration Limits of Reticle Stage {#acceleration-limits-of-reticle-stage}


### Position Measurement {#position-measurement}


#### Alignment Sensor {#alignment-sensor}


#### Keeping the Wafer in Focus {#keeping-the-wafer-in-focus}


#### Dual-Stage Measurement and Exposure {#dual-stage-measurement-and-exposure}


#### Long-Range Incremental Measurement System {#long-range-incremental-measurement-system}


##### Real-Time Metrology Loop {#real-time-metrology-loop}


### Motion Control {#motion-control}


#### Feedforward and Feedback Control {#feedforward-and-feedback-control}


##### Thermal, The Final Frontier {#thermal-the-final-frontier}


#### The Mass Dilemma {#the-mass-dilemma}

> A reduced mass requires improved system dynamics that enable a higher control bandwidth to compensate for the increase sensitivity for external vibrations.


### Future Developments in IC Lithography {#future-developments-in-ic-lithography}


### Main Design Rules for Precision {#main-design-rules-for-precision}


## Bibliography {#bibliography}

<style>.csl-entry{text-indent: -1.5em; margin-left: 1.5em;}</style><div class="csl-bib-body">
  <div class="csl-entry"><a id="citeproc_bib_item_1"></a>Schmidt, R Munnig, Georg Schitter, and Adrian Rankers. 2020. <i>The Design of High Performance Mechatronics - Third Revised Edition</i>. Ios Press.</div>
</div>
