+++
title = "Eddy Current Damping"
draft = false
+++

Tags
: [Passive Damping]({{< relref "passive_damping.md" >}})

<https://courses.lumenlearning.com/suny-physics/chapter/23-4-eddy-currents-and-magnetic-damping/>


## Vacuum compatible magnets {#vacuum-compatible-magnets}

<https://www.mceproducts.com/articles/magnets-in-vacuum-applications>


## Estimate the damping {#estimate-the-damping}


### Formulas {#formulas}

From (<a href="#citeproc_bib_item_1">Zuo 2004</a>):
The empirical formula for damping coefficient (Ns/m) of an eddy current damper is:

\begin{equation} \label{eq:damping\_formula}
C = C\_0 B^2 t A \sigma
\end{equation}

with:

-   \\(B\\) is the magnetic flux density in [T] or in [Vs/m2]
-   \\(t\\) is the thickness of the conductor plate in [m]
-   \\(A\\) is the area of the conductor intersected by the magnetic field in [m2]
-   \\(\sigma\\) is the electrical conductivity of the conductor material [S/m]
-   \\(C\_0\\) is a dimensionless coefficient to account for the shapes and sizes of the conductor and magnetic field

\\(C\_0 = 1\\) corresponds to a conductor with conductivity \\(\sigma\\) inside a uniform magnetic field and conductivity infinite outside this field.
A typical value of \\(C\_0\\) is about 0.25-0.4 for a conductor plate with area 2 to 5 times that of the magnetic field.

From <eq:damping_formula>, we see that the damping coefficient is proportional to:

-   the square of the magnetic flux density \\(B\\). Therefore it is very important to have large magnetic field strengh
-   the thickness \\(t\\) of the conductor. However due to **skin depth effect**,  the benefit of increasing the thickness is limited.
    The apparent conductivity \\(\sigma\_e\\) is:

    \begin{equation}
      \sigma\_e = \frac{2\delta\_s}{t}(1 - e^{-\frac{t}{2\delta\_s}})\sigma
    \end{equation}

    where \\(\delta\_s\\) is the skin depth in [m] of the conductor with permeability \\(\mu\\) in [H/m] at frequency \\(f\\) in [Hz]:

    \begin{equation}
      \delta\_s = \sqrt{\frac{2}{2 \pi f \cdot \mu \cdot \sigma}}
    \end{equation}

An eddy current damper is developed in (<a href="#citeproc_bib_item_1">Zuo 2004</a>).
The magnets have alternating poles to optimize the eddy current damping (stronger varying magnetic field).
See Figures [1](#figure--fig:zuo04-eddy-current-magnets) and [2](#figure--fig:zuo04-eddy-current-setup).

<a id="figure--fig:zuo04-eddy-current-magnets"></a>

{{< figure src="/ox-hugo/zuo04_eddy_current_magnets.png" caption="<span class=\"figure-number\">Figure 1: </span>(left) Magnetic field and conductor plates assemblies, (right) magnet arrays" >}}

<a id="figure--fig:zuo04-eddy-current-setup"></a>

{{< figure src="/ox-hugo/zuo04_eddy_current_setup.png" caption="<span class=\"figure-number\">Figure 1: </span>Single DoF system damped by eddy current damper" >}}


### Numerical Simulation {#numerical-simulation}

It is possible to estimate that with FEM simulation: <https://www.youtube.com/watch?v=_1pgyj4lD7Q>

An approximation is done bellow.

```matlab
B = 1.0; % Magnetic Flux Density [T]
t = 5e-3; % Thickness [m]
A = 50e-3*50e-3; % Area [m2]
sigma = 6e7; % Copper conductivity [S/m]
C0 = 0.5; % [-]
```

```matlab
C = C0*B^2*t*A*sigma; % Damping in [N/(m/s)]
```

```text
C = 375 [N/(m/s)]
```

```matlab
m = 10; % [kg]
k = m*(2*pi*10)^2; % [N/m]
```

```matlab
xi = 1/2*C/sqrt(k*m);
```

```text
xi = 0.298
```


## Bibliography {#bibliography}

<style>.csl-entry{text-indent: -1.5em; margin-left: 1.5em;}</style><div class="csl-bib-body">
  <div class="csl-entry"><a id="citeproc_bib_item_1"></a>Zuo, Lei. 2004. “Element and System Design for Active and Passive Vibration Isolation.” Massachusetts Institute of Technology.</div>
</div>
