+++
title = "Electronic Noise"
author = ["Dehaeze Thomas"]
draft = false
+++

Tags
: [Electronics]({{< relref "electronics.md" >}}), [Signal to Noise Ratio]({{< relref "signal_to_noise_ratio.md" >}})


## Thermal (Johnson) Noise {#thermal--johnson--noise}

Thermal noise is generated by the thermal agitation of the electrons inside the electrical conductor.
Its Power Spectral Density is equal to:

\begin{equation}
S\_T \approx 4 k T \text{Re}(Z(f)) \quad [V^2/Hz]
\end{equation}

with:
with \\(k = 1.38 \cdot 10^{-23} \\,[J/K]\\) the Boltzmann's constant, \\(T\\) the temperature [K] and \\(Z(f)\\) the frequency dependent impedance of the system.

This noise can be modeled as a voltage source in series with the system impedance.

| Resistance      | PSD \\([V^2 / Hz]\\)     | ASD \\([V/\sqrt{Hz}]\\)  | RMS (1kHz) | RMS (10kHz) |
|-----------------|--------------------------|--------------------------|------------|-------------|
| \\(1 \Omega\\)  | \\(1.6 \cdot 10^{-20}\\) | \\(1.2 \cdot 10^{-10}\\) | 4nV        | 130nV       |
| \\(1 k\Omega\\) | \\(1.6 \cdot 10^{-17}\\) | \\(4 \cdot 10^{-9}\\)    | 130nV      | 4uV         |
| \\(1 M\Omega\\) | \\(1.6 \cdot 10^{-14}\\) | \\(1.2 \cdot 10^{-7}\\)  | 4uV        | 130uV       |


## Shot Noise {#shot-noise}

Seen with junctions in a transistor.
It has a white spectral density:

\begin{equation}
S\_S = 2 q\_e i\_{dc} \ [A^2/Hz]
\end{equation}

with \\(q\_e\\) the electronic charge (\\(1.6 \cdot 10^{-19}\\, [C]\\)), \\(i\_{dc}\\) the average current [A].

<div class="exampl">

A current of 1 A will introduce noise with a STD of \\(10 \cdot 10^{-9}\\,[A]\\) from zero up to one kHz.

</div>


## Excess Noise (or \\(1/f\\) noise) {#excess-noise--or-1-f-noise}

It results from fluctuating conductivity due to imperfect contact between two materials.
The PSD of excess noise increases when the frequency decreases:
\\[ S\_E = \frac{K\_f}{f^\alpha}\ [V^2/Hz] \\]
where \\(K\_f\\) is dependent on the average voltage drop over the resistor and the index \\(\alpha\\) is usually between 0.8 and 1.4, and often set to unity for approximate calculation.


## Noise of Amplifiers {#noise-of-amplifiers}

The noise of amplifiers can be modelled as shown in Figure [1](#figure--fig:electronic-amplifier-noise).

<a id="figure--fig:electronic-amplifier-noise"></a>

{{< figure src="/ox-hugo/electronic_amplifier_noise.png" caption="<span class=\"figure-number\">Figure 1: </span>Amplifier noise model" >}}

The identification of this noise is a two steps process:

1.  The amplifier input is short-circuited such that only \\(V^2(f)\\) has an impact on the output.
    The output noise is measured and \\(V^2\\) in \\([V^2/Hz]\\) is identified
2.  The amplifier input is open-circuited such that only \\(I^2(f)\\) has an impact on the output.
    The output noise is measured and \\(I^2(f)\\) in \\([A^2/Hz]\\) is identified.


## Bibliography {#bibliography}

<style>.csl-entry{text-indent: -1.5em; margin-left: 1.5em;}</style><div class="csl-bib-body">
</div>
