+++
title = "Electronic Passive Filters"
author = ["Dehaeze Thomas"]
draft = false
+++

Tags
:


## First Order Low Pass Filter {#first-order-low-pass-filter}

<a id="figure--fig:analog-filt-first-order-lpf"></a>

{{< figure src="/ox-hugo/analog_filt_first_order_lpf.png" caption="<span class=\"figure-number\">Figure 1: </span>First Order Low Pass Filter using an RC circuit" >}}

\begin{equation}
\boxed{\frac{V\_o}{V\_i}(s) = \frac{1}{1 + \frac{s}{\omega\_0}}, \quad \omega\_0 = \frac{1}{RC}}
\end{equation}

\begin{equation}
Z\_f(s) = \frac{V\_i}{i\_i}(s) = \frac{1 + RC \cdot s}{C \cdot s}
\end{equation}

```matlab
%% First Order Low Pass Filter
R = 1e3; % [Ohm]
C = 1e-6; % [F]
```

```matlab
G = 1/(1 + R*C*s); % Filter Transfer Function
Z = (1 + R*C*s)/(C*s); % Filter Impedance
```

<a id="figure--fig:analog-filt-first-order-lpf-characteristics"></a>

{{< figure src="/ox-hugo/analog_filt_first_order_lpf_characteristics.png" caption="<span class=\"figure-number\">Figure 2: </span>First Order Low Pass Filter - Filter transfer function and filter impedance" >}}


## First Order High Pass Filter {#first-order-high-pass-filter}

<a id="figure--fig:analog-filt-first-order-hpf"></a>

{{< figure src="/ox-hugo/analog_filt_first_order_hpf.png" caption="<span class=\"figure-number\">Figure 3: </span>First Order High Pass Filter using an RC circuit" >}}

\begin{equation}
\boxed{\frac{V\_o}{V\_i}(s) = \frac{\frac{s}{\omega\_0}}{1 + \frac{s}{\omega\_0}}, \quad \omega\_0 = \frac{1}{RC}}
\end{equation}

\begin{equation}
Z\_f(s) = \frac{V\_i}{i\_i}(s) = \frac{1 + RC \cdot s}{C \cdot s}
\end{equation}

```matlab
%% First Order High Pass Filter
R = 1e3; % [Ohm]
C = 1e-6; % [F]
```

```matlab
G = R*C*s/(1 + R*C*s); % Filter Transfer Function
Z = (1 + R*C*s)/(C*s); % Filter Impedance
```

<a id="figure--fig:analog-filt-first-order-hpf-characteristics"></a>

{{< figure src="/ox-hugo/analog_filt_first_order_hpf_characteristics.png" caption="<span class=\"figure-number\">Figure 4: </span>First Order High Pass Filter - Filter transfer function and filter impedance" >}}


## Second Order Low Pass Filter {#second-order-low-pass-filter}

<a id="figure--fig:analog-filt-second-order-lpf"></a>

{{< figure src="/ox-hugo/analog_filt_second_order_lpf.png" caption="<span class=\"figure-number\">Figure 5: </span>Second Order Low Pass Filter using an RLC circuit" >}}

\begin{equation}
\boxed{\frac{V\_o}{V\_i}(s) = \frac{1}{1 + 2 \xi \frac{s}{\omega\_0} + \frac{s^2}{\omega\_0^2}}, \quad \omega\_0 = \frac{1}{\sqrt{LC}},\quad \xi = \frac{1}{2R\sqrt{LC}}}
\end{equation}

\begin{equation}
Z\_f(s) = \frac{V\_i}{i\_i}(s) = L \cdot s + \frac{R}{1 + RC \cdot s}
\end{equation}

```matlab
%% Second Order Low Pass Filter
R = 1e2; % [Ohm]
C = 1e-5; % [F]
L = 1e-2; % [H]
```

```matlab
G = 1/(1 + L/R*s + C*L*s^2); % Filter Transfer Function
Z = L*s + (R)/(1 + R*C*s); % Filter Impedance
```

<a id="figure--fig:analog-filt-second-order-lpf-characteristics"></a>

{{< figure src="/ox-hugo/analog_filt_second_order_lpf_characteristics.png" caption="<span class=\"figure-number\">Figure 6: </span>Second Order Low Pass Filter - Filter transfer function and filter impedance" >}}


## Second Order High Pass Filter {#second-order-high-pass-filter}

<a id="figure--fig:analog-filt-second-order-hpf"></a>

{{< figure src="/ox-hugo/analog_filt_second_order_hpf.png" caption="<span class=\"figure-number\">Figure 7: </span>Second Order High Pass Filter using an RLC circuit" >}}


## Bibliography {#bibliography}

<style>.csl-entry{text-indent: -1.5em; margin-left: 1.5em;}</style><div class="csl-bib-body">
</div>
