+++
title = "Position Sensors"
author = ["Dehaeze Thomas"]
draft = false
category = "equipment"
+++

Tags
: [Inertial Sensors]({{< relref "inertial_sensors.md" >}}), [Force Sensors]({{< relref "force_sensors.md" >}}), [Sensor Fusion]({{< relref "sensor_fusion.md" >}}), [Signal Conditioner]({{< relref "signal_conditioner.md" >}}), [Signal to Noise Ratio]({{< relref "signal_to_noise_ratio.md" >}})


## Types of Positioning sensors {#types-of-positioning-sensors}

High precision positioning sensors include:

-   [Interferometers]({{< relref "interferometers.md" >}})
-   [Capacitive Sensors]({{< relref "capacitive_sensors.md" >}})
-   [LVDT]({{< relref "linear_variable_differential_transformers.md" >}})
-   [Eddy Current Sensors]({{< relref "eddy_current_sensors.md" >}})
-   [Encoders]({{< relref "encoders.md" >}})
-   [Quadrant Photodiodes]({{< relref "quadrant_photodiodes.md" >}})


## Reviews of Relative Position Sensors {#reviews-of-relative-position-sensors}

-   Fleming, A. J., A review of nanometer resolution position sensors: operation and performance (<a href="#citeproc_bib_item_2">Fleming 2013</a>) ([Notes]({{< relref "fleming13_review_nanom_resol_posit_sensor.md" >}}))
-   (<a href="#citeproc_bib_item_3">Gao et al. 2015</a>)

[Table 1](#table--tab:characteristics-relative-sensor) is taken from (<a href="#citeproc_bib_item_1">Collette et al. 2011</a>).

<a id="table--tab:characteristics-relative-sensor"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:characteristics-relative-sensor">Table 1</a>:</span>
  Characteristics of relative measurement sensors
</div>

| Technology     | Frequency  | Resolution     | Range        | T Range     |
|----------------|------------|----------------|--------------|-------------|
| LVDT           | DC-200 Hz  | 10 nm rms      | 1-10 mm      | -50,100 °C  |
| Eddy current   | 5 kHz      | 0.1-100 nm rms | 0.5-55 mm    | -50,100 °C  |
| Capacitive     | DC-100 kHz | 0.05-50 nm rms | 50 nm - 1 cm | -40,100 °C  |
| Interferometer | 300 kHz    | 0.1 nm rms     | 10 cm        | -250,100 °C |
| Encoder        | DC-1 MHz   | 1 nm rms       | 7-27 mm      | 0,40 °C     |
| Bragg Fibers   | DC-150 Hz  | 0.3 nm rms     | 3.5 cm       | -30,80 °C   |

[Table 2](#table--tab:summary-position-sensors) it taken from (<a href="#citeproc_bib_item_2">Fleming 2013</a>).

<a id="table--tab:summary-position-sensors"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:summary-position-sensors">Table 2</a>:</span>
  Summary of position sensor characteristics. The dynamic range (DNR) and resolution are approximations based on a full-scale range of 100um and a first order bandwidth of \(1 kHz\)
</div>

| Sensor Type    | Range                          | DNR     | Resolution | Max. BW     | Accuracy  |
|----------------|--------------------------------|---------|------------|-------------|-----------|
| Metal foil     | \\(10-500 \mu m\\)             | 230 ppm | 23 nm      | 1-10 kHz    | 1% FSR    |
| Piezoresistive | \\(1-500 \mu m\\)              | 5 ppm   | 0.5 nm     | &gt;100 kHz | 1% FSR    |
| Capacitive     | \\(10 \mu m\\) to \\(10 mm\\)  | 24 ppm  | 2.4 nm     | 100 kHz     | 0.1% FSR  |
| Electrothermal | \\(10 \mu m\\) to \\(1 mm\\)   | 100 ppm | 10 nm      | 10 kHz      | 1% FSR    |
| Eddy current   | \\(100 \mu m\\) to \\(80 mm\\) | 10 ppm  | 1 nm       | 40 kHz      | 0.1% FSR  |
| LVDT           | \\(0.5-500 mm\\)               | 10 ppm  | 5 nm       | 1 kHz       | 0.25% FSR |
| Interferometer | Meters                         |         | 0.5 nm     | &gt;100kHz  | 1 ppm FSR |
| Encoder        | Meters                         |         | 6 nm       | &gt;100kHz  | 5 ppm FSR |

Capacitive Sensors and Eddy-Current sensors are compare [here](https://www.lionprecision.com/comparing-capacitive-and-eddy-current-sensors/).

[Figure 1](#figure--fig:position-sensors-thurner15) is taken from (<a href="#citeproc_bib_item_4">Thurner et al. 2015</a>).

<a id="figure--fig:position-sensors-thurner15"></a>

{{< figure src="/ox-hugo/position_sensors_thurner15.png" caption="<span class=\"figure-number\">Figure 1: </span>Overview of range and precision of different position displacement sensors" >}}


## Bibliography {#bibliography}

<style>.csl-entry{text-indent: -1.5em; margin-left: 1.5em;}</style><div class="csl-bib-body">
  <div class="csl-entry"><a id="citeproc_bib_item_1"></a>Collette, C, K Artoos, M Guinchard, S Janssens, P Carmona Fernandez, and C Hauviller. 2011. “Review of Sensors for Low Frequency Seismic Vibration Measurement.” CERN.</div>
  <div class="csl-entry"><a id="citeproc_bib_item_2"></a>Fleming, Andrew J. 2013. “A Review of Nanometer Resolution Position Sensors: Operation and Performance.” <i>Sensors and Actuators a: Physical</i> 190: 106–26. doi:<a href="https://doi.org/10.1016/j.sna.2012.10.016">10.1016/j.sna.2012.10.016</a>.</div>
  <div class="csl-entry"><a id="citeproc_bib_item_3"></a>Gao, W., S.W. Kim, H. Bosse, H. Haitjema, Y.L. Chen, X.D. Lu, W. Knapp, A. Weckenmann, W.T. Estler, and H. Kunzmann. 2015. “Measurement Technologies for Precision Positioning.” <i>CIRP Annals</i> 64 (2): 773–96. doi:<a href="https://doi.org/10.1016/j.cirp.2015.05.009">10.1016/j.cirp.2015.05.009</a>.</div>
  <div class="csl-entry"><a id="citeproc_bib_item_4"></a>Thurner, Klaus, Francesca Paola Quacquarelli, Pierre-François Braun, Claudio Dal Savio, and Khaled Karrai. 2015. “Fiber-Based Distance Sensing Interferometry.” <i>Applied Optics</i> 54 (10). Optical Society of America: 3051–63.</div>
</div>
