+++
title = "Stepper Motor"
author = ["Dehaeze Thomas"]
draft = false
category = "equipment"
+++

Tags
:


## Types of Stepper motors {#types-of-stepper-motors}

<https://blog.orientalmotor.com/stepper-motor-basics-pm-vs-vr-vs-hybrid>

-   Permanent Magnet
-   Variable Reluctance
-   Hybrid

<a id="figure--fig:stepper-two-phase-hybrid-stepper"></a>

{{< figure src="/ox-hugo/stepper_two_phase_hybrid_stepper.png" caption="<span class=\"figure-number\">Figure 1: </span>Interior of a two phase hybrid stepper motor. This motor has eight windings and 50 roto teeth" >}}

<a id="figure--fig:stepper-hybrid-schematic"></a>

{{< figure src="/ox-hugo/stepper_hybrid_schematic.png" caption="<span class=\"figure-number\">Figure 2: </span>Schematic of a two phase hybrid stepper motor. This motor has four windings and 15 pole pairs" >}}


## Micro Stepping {#micro-stepping}

From (<a href="#citeproc_bib_item_2">Ronquist and Winroth 2016</a>):

> By varying the magnitude and direction of the winding currents, the rotor is continuously attracted in the desired direction.
> A "step" occurs whenever a rotor tooth moves slightly to align itself to an electromagnet tooth.
>
> It is possible to decrease the step size of the hybrid stepper motor by using a control logic called **microstepping**.
> As opposed to fully exciting each phase in turn, as described previously, microstepping involves transitioning between each phase shift.
> That is, the current references are defined by sinusoidal signals displaced 90 electrical degrees from each other.
> For most time instances, then, both phases are excited to a certain degree.
> The result is that the electric position vector can be placed between two teeth.
> The resolution of the motor has therefore been increased.

From (<a href="#citeproc_bib_item_1">Condit 2004</a>):

> There are several factors that affect the linearity of microstepping in real motors.
> The first limitation is static friction in the system.
>
> [...]
>
> Another limitation is the fact that the torque versus position curve is not perfectly sinusoidal.
> The toothed shape of the motor and other physical characteristics of the motor contribute to this.
> Figure [3](#figure--fig:stepper-real-pos-vs-actual-pos) shows a plot of actual position vs expected position for a typical motor.

<a id="figure--fig:stepper-real-pos-vs-actual-pos"></a>

{{< figure src="/ox-hugo/stepper_real_pos_vs_actual_pos.png" caption="<span class=\"figure-number\">Figure 3: </span>Real vs actuator rotor position" >}}


## Open Loop errors {#open-loop-errors}

Nice references:

-   (<a href="#citeproc_bib_item_3">Vyas, Patel, and Shah 2015</a>)
-   (<a href="#citeproc_bib_item_2">Ronquist and Winroth 2016</a>)
-   <http://www.euclidres.com/apps/stepper_motor/stepper.html>

<div class="seealso">

References about these errors can be search for using "torque ripple", "Cogging torque" and "load dependent error" keywords.

</div>


### Error with period equal to one **turn** {#error-with-period-equal-to-one-turn}

A stepper motor has a position error with a period equal to a full turn.

An example is shown in Figure [4](#figure--fig:stepper-error-one-turn-period) (from (<a href="#citeproc_bib_item_2">Ronquist and Winroth 2016</a>)).
The high frequency errors that can be observed have a period of one step (i.e. 200 periods each turn).

<a id="figure--fig:stepper-error-one-turn-period"></a>

{{< figure src="/ox-hugo/stepper_error_one_turn_period.png" caption="<span class=\"figure-number\">Figure 4: </span>Angle error of the stepper motor during a 100rpm (i.e. 0.6s per turn)" >}}


### Error with period equal to one **step** {#error-with-period-equal-to-one-step}

For a two phase stepper motor, there are (typically) **200 steps per revolution** (i.e. 1.8 degrees per step).

Between each step, even when using some micro-stepping, there are some position errors that are due to non-perfect magnetic and electromagnetic fields.

The period of this error is corresponding to 200 period/revolution.

Then scanning, this can lead to **high frequency vibrations**.

This is what is typically limiting the accuracy of the stepper motor (usually specified in between 3% and 5% of the step increment).
This is approximately corresponding to **1mrad** and can be around 0.1mrad for best stepper motors.

<div class="exampl">

Consider a stepper motor with 200 steps by turn attached to a ball-screw with a pitch of 1mm per turn.
A rotation of 1 turn per second will induce vibrations at 200Hz with an amplitude of \\(1\\,\mu m\\).

</div>

Note that this error is not a pure sine, it also has some harmonics.

One way to reduce these errors is to use a ball-screw mechanism with a smaller pitch (or a reduction gearbox).
The price to pay is smaller velocity (and even high vibration frequencies for the same velocity).


### Load Dependent Error {#load-dependent-error}

If the electromagnetic torque would be the only torque acting on the system, the electrical angle generated by the control system would correspond directly to the reference angle.

The position error is to a large degree due to the so called load angle when the motor is positioned by an open-loop controller.
The load angle results from applying an external torque to the stepper motor, **causing the magnetic rotor to be out of phase with the electrical field**.

The most common way to limit these errors is to always operate the motor with its rated winding currents.
This results in significant energy losses and heating of the motor which deprive the motor of its efficiency.

Another option is to use a position sensor such as an encoder with a feedback controller.


## Manufacturers {#manufacturers}

| Manufacturers                                                            | Country        |
|--------------------------------------------------------------------------|----------------|
| [AML](https://arunmicro.com/)                                            | United Kingdom |
| [Sanyo](https://www.sanyodenki.com/catalogs/servo/stepping_systems.html) |                |


## 2 phase VS 5 phase stepper motor {#2-phase-vs-5-phase-stepper-motor}

<https://www.orientalmotor.com/stepper-motors/technology/2-phase-vs-5-phase-stepper-motors.html>


## Bibliography {#bibliography}

<style>.csl-entry{text-indent: -1.5em; margin-left: 1.5em;}</style><div class="csl-bib-body">
  <div class="csl-entry"><a id="citeproc_bib_item_1"></a>Condit, Reston. 2004. “Stepping Motors Fundamentals.” Microchip Technology.</div>
  <div class="csl-entry"><a id="citeproc_bib_item_2"></a>Ronquist, Anton, and Birger Winroth. 2016. “Estimation and Compensation of Load-Dependent Position Error in a Hybrid Stepper Motor.” Linköping University, Automatic Control; Linköping University, Automatic Control.</div>
  <div class="csl-entry"><a id="citeproc_bib_item_3"></a>Vyas, Darshit C, Jinesh G Patel, and Mrs Heli A Shah. 2015. “Microstepping of Stepper Motor and Sources of Errors in Microstepping System.” <i>Int. Journal of Engineering Research and General Science</i> 3 (2).</div>
</div>
